@@ -147,7 +147,7 @@ public:
 	and the activity group id of both of them is 0 or of both of them is != 0, returns true.
 	TODO: add a more intelligent comparison
 	*/
-	bool operator==(Activity &a);
+	bool operator==(const Activity &a);
 
 	//internal structure
 	
@@ -262,7 +262,7 @@ public:
 	void computeInternalStructure(Rules& r);
 
 	/**
-	Returns a representation of this activity (xml format).
+	Returns a representation of this activity (in XML format).
 	*/
 	QString getXmlDescription(Rules& r);
 
