@@ -31,14 +31,11 @@ File solution.cpp
 
 #include "matrix.h"
 
-#include <QMap>
 #include <QMultiMap>
 
 #include <algorithm>
 
-//extern bool breakDayHour[MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY];
 extern Matrix2D<bool> breakDayHour;
-//extern bool teacherNotAvailableDayHour[MAX_TEACHERS][MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY];
 extern Matrix3D<bool> teacherNotAvailableDayHour;
 
 //critical function here - must be optimized for speed
@@ -47,13 +44,14 @@ void Solution::copy(Rules& r, Solution& c){
 
 	assert(r.internalStructureComputed);
 	
+	this->times.resize(r.nInternalActivities);
+	this->rooms.resize(r.nInternalActivities);
 	this->realRoomsList.resize(r.nInternalActivities);
 	for(int i=0; i<r.nInternalActivities; i++){
 		this->times[i] = c.times[i];
-		this->rooms[i]=c.rooms[i];
+		this->rooms[i] = c.rooms[i];
 		this->realRoomsList[i]=c.realRoomsList[i];
 	}
-	//memcpy(times, c.times, r.nActivities * sizeof(times[0]));
 	
 	this->changedForMatrixCalculation=c.changedForMatrixCalculation;
 
@@ -69,7 +67,37 @@ void Solution::copy(Rules& r, Solution& c){
 	nPlacedActivities=c.nPlacedActivities;
 }
 
-void Solution::init(Rules& r){
+//critical function here - must be optimized for speed
+void Solution::copyForHighestStage(Rules& r, Solution& c){
+	this->_fitness=-1;
+
+	assert(r.internalStructureComputed);
+	
+	this->times.resize(r.nInternalActivities);
+	this->rooms.resize(r.nInternalActivities);
+	this->realRoomsList.resize(r.nInternalActivities);
+	for(int i=0; i<r.nInternalActivities; i++){
+		this->times[i] = c.times[i];
+		this->rooms[i] = c.rooms[i];
+		this->realRoomsList[i]=c.realRoomsList[i];
+	}
+	
+	this->changedForMatrixCalculation=true;
+
+	//I commented out the following lines, to avoid useless copying.
+	//added in version 5.2.0
+	//conflictsWeightList=c.conflictsWeightList;
+	//conflictsDescriptionList=c.conflictsDescriptionList;
+	//conflictsTotal=c.conflictsTotal;
+	
+	//teachersMatrixReady=false;
+	//subgroupsMatrixReady=false;
+	//roomsMatrixReady=false;
+	
+	//nPlacedActivities=c.nPlacedActivities;
+}
+
+/*void Solution::init(Rules& r){
 	assert(r.internalStructureComputed);
 
 	realRoomsList.resize(r.nInternalActivities);
@@ -81,17 +109,19 @@ void Solution::init(Rules& r){
 	this->_fitness=-1;
 	
 	this->changedForMatrixCalculation=true;
-}
+}*/
 
 void Solution::makeUnallocated(Rules& r){
 	assert(r.initialized);
 	assert(r.internalStructureComputed);
 
-	realRoomsList.resize(r.nInternalActivities);
+	this->times.resize(r.nInternalActivities);
+	this->rooms.resize(r.nInternalActivities);
+	this->realRoomsList.resize(r.nInternalActivities);
 	for(int i=0; i<r.nInternalActivities; i++){
 		this->times[i]=UNALLOCATED_TIME;
 		this->rooms[i]=UNALLOCATED_SPACE;
-		realRoomsList[i].clear();
+		this->realRoomsList[i].clear();
 	}
 
 	this->_fitness=-1;
@@ -106,7 +136,7 @@ double Solution::fitness(Rules& r, FakeString* conflictsString){
 	if(this->_fitness>=0)
 		assert(this->changedForMatrixCalculation==false);
 		
-	if(this->_fitness>=0 && conflictsString==NULL)
+	if(this->_fitness>=0 && conflictsString==nullptr)
 	//If you want to see the log, you have to recompute the fitness, even if it is
 	//already computed
 		return this->_fitness;
@@ -166,16 +196,16 @@ double Solution::fitness(Rules& r, FakeString* conflictsString){
 	//sort descending according to conflicts in O(n log n)
 	int ttt=conflictsWeightList.count();
 		
-	QMultiMap<double, QString> map;
+	QMultiMap<double, QString> conflictsMap;
 	assert(conflictsWeightList.count()==conflictsDescriptionList.count());
 	for(int i=0; i<conflictsWeightList.count(); i++)
-		map.insert(conflictsWeightList.at(i), conflictsDescriptionList.at(i));
+		conflictsMap.insert(conflictsWeightList.at(i), conflictsDescriptionList.at(i));
 		
 	conflictsWeightList.clear();
 	conflictsDescriptionList.clear();
 	
-	QMultiMap<double, QString>::const_iterator i=map.constBegin();
-	while(i!=map.constEnd()){
+	QMultiMap<double, QString>::const_iterator i=conflictsMap.constBegin();
+	while(i!=conflictsMap.constEnd()){
 		conflictsWeightList.append(i.key());
 		conflictsDescriptionList.append(i.value());
 		i++;
@@ -262,7 +292,7 @@ int Solution::getSubgroupsMatrix(Rules& r, Matrix3D<int>& a){
 
 //The following 2 functions (getTeachersTimetable & getSubgroupsTimetable)
 //are very similar to the above 2 ones (getTeachersMatrix & getSubgroupsMatrix)
-void Solution::getTeachersTimetable(Rules& r, Matrix3D<int>& a, Matrix3D<QList<int> >& b){
+void Solution::getTeachersTimetable(Rules& r, Matrix3D<int>& a, Matrix3D<QList<int>>& b){
 	assert(r.initialized);
 	assert(r.internalStructureComputed);
 	
@@ -372,7 +402,6 @@ void Solution::getTeachersTimetable(Rules& r, Matrix3D<int>& a, Matrix3D<QList<i
 		}
 	}
 	//END of Code contributed by Volker Dirr (https://timetabling.de/) END
-	//bool visited[MAX_TEACHERS];
 	Matrix1D<bool> visited;
 	visited.resize(r.nInternalTeachers);
 	for(d=0; d<r.nDaysPerWeek; d++){
@@ -471,7 +500,7 @@ int Solution::getRoomsMatrix(
 void Solution::getRoomsTimetable(
 	Rules& r,
 	Matrix3D<int>& a,
-	Matrix3D<QList<int> >& va)
+	Matrix3D<QList<int>>& va)
 {
 	assert(r.initialized);
 	assert(r.internalStructureComputed);
