@@ -37,13 +37,15 @@ int STUDENTS_COMBO_BOXES_STYLE=STUDENTS_COMBO_BOXES_STYLE_SIMPLE;
 /**
 FET version
 */
-const QString FET_VERSION="5.48.1";
+const QString FET_VERSION="6.7.6";
 
 /**
 FET language
 */
 QString FET_LANGUAGE="en_US";
 
+QString FET_LANGUAGE_WITH_LOCALE="en_US";
+
 /**
 The output directory. Please be careful when editing it,
 because the functions add a FILE_SEP sign at the end of it
@@ -57,7 +59,7 @@ bool LANGUAGE_STYLE_RIGHT_TO_LEFT;
 QString LANGUAGE_FOR_HTML;
 
 /**
-Timetable html css javaScript Level, by Volker Dirr
+Timetable HTML CSS JavaScript level, by Volker Dirr
 */
 int TIMETABLE_HTML_LEVEL;
 
@@ -79,7 +81,7 @@ bool TIMETABLE_HTML_REPEAT_NAMES;
 
 bool VERBOSE;
 
-//these hashes are needed to get the IDs for html and css in timetableexport and statistics
+//these hashes are needed to get the IDs for HTML and CSS in timetableexport and statistics
 /*QHash<QString, QString> hashSubjectIDs;
 QHash<QString, QString> hashActivityTagIDs;
 QHash<QString, QString> hashStudentIDs;
@@ -88,19 +90,21 @@ QHash<QString, QString> hashRoomIDs;
 QHash<QString, QString> hashDayIDs;*/
 
 /**
-A log file explaining how the xml input file was parsed
+A log file explaining how the XML input file was parsed
 */
 const QString XML_PARSING_LOG_FILENAME="file_open.log";
 
 /**
 The predefined names of the days of the week
 */
+/*
 const QString PREDEFINED_DAYS_OF_THE_WEEK[]={"Monday", "Tuesday", "Wednesday",
 	"Thursday", "Friday", "Saturday", "Sunday", "Monday2",
 	"Tuesday2", "Wednesday2", "Thursday2", "Friday2", "Saturday2", "Sunday2",
 	"Monday3", "Tuesday3", "Wednesday3",
 	"Thursday3", "Friday3", "Saturday3", "Sunday3", "Monday4",
 	"Tuesday4", "Wednesday4", "Thursday4", "Friday4", "Saturday4", "Sunday4"};
+*/
 
 /**
 File and directory separator
@@ -291,8 +295,8 @@ void initRandomKnuth()
 	assert(tttt==2111618746);
 	//////////
 	
-	//unsigned tt=unsigned(time(NULL));
-	qint64 tt=qint64(time(NULL));
+	//unsigned tt=unsigned(time(nullptr));
+	qint64 tt=qint64(time(nullptr));
 	
 	//XX is the current time
 	//XX = 1 + ( (unsigned(tt)) % (unsigned(MM-1)) );
@@ -360,7 +364,7 @@ int randomKnuth(int k)
 }
 */
 
-MRG32k3a rng;
+//MRG32k3a rng;
 
 const qint64 MRG32k3a::m1 = Q_INT64_C(4294967087);
 const qint64 MRG32k3a::m2 = Q_INT64_C(4294944443);
@@ -427,7 +431,7 @@ void MRG32k3a::initializeMRG32k3a()
 {
 	qint64 _s10, _s11, _s12, _s20, _s21, _s22;
 
-	//qint64 tt=qint64(time(NULL));
+	//qint64 tt=qint64(time(nullptr));
 	
 	std::chrono::seconds s=std::chrono::duration_cast<std::chrono::seconds>(std::chrono::system_clock::now().time_since_epoch());
 	qint64 si=static_cast<qint64>(s.count());
