@@ -45,34 +45,36 @@ public:
 	TimetableExport();
 	~TimetableExport();
 	
-	static void stringToColor(QString s, int* r, int* g, int* b);
+	static void stringToColor(const QString& s, int& r, int& g, int& b);
 
-	static void getStudentsTimetable(Solution& c);
+	/*static void getStudentsTimetable(Solution& c);
 	static void getTeachersTimetable(Solution& c);
-	static void getRoomsTimetable(Solution& c);
+	static void getRoomsTimetable(Solution& c);*/
+	static void getStudentsTeachersRoomsTimetable(Solution& c);
 	static void getNumberOfPlacedActivities(int& number1, int& number2);
 
 	static void writeSimulationResults(QWidget* parent);
 	static void writeHighestStageResults(QWidget* parent);
-	static void writeSimulationResults(QWidget* parent, int n); //write in a directory with number n (for multiple generation)
+	static void writeSimulationResults(QWidget* parent, int n, bool highest=false); //write in a directory with number n (for multiple generation)
+	//If highest==true, it writes a partial highest timetable.
 	static void writeSimulationResultsCommandLine(QWidget* parent, const QString& outputDirectory);
 	
-	static void writeRandomSeed(QWidget* parent, bool before);
-	static void writeRandomSeed(QWidget* parent, int n, bool before); //write in a directory with number n (for multiple generation)
-	static void writeRandomSeedCommandLine(QWidget* parent, const QString& outputDirectory, bool before);
-	static void writeRandomSeedFile(QWidget* parent, const QString& filename, bool before);
+	static void writeRandomSeed(QWidget* parent, const MRG32k3a& rng, bool before);
+	static void writeRandomSeed(QWidget* parent, const MRG32k3a& rng, int n, bool before); //write in a directory with number n (for multiple generation)
+	static void writeRandomSeedCommandLine(QWidget* parent, const MRG32k3a& rng, const QString& outputDirectory, bool before);
+	static void writeRandomSeedFile(QWidget* parent, const MRG32k3a& rng, const QString& filename, bool before);
 	
 	static void writeTimetableDataFile(QWidget* parent, const QString& filename);
 	
 	static void writeReportForMultiple(QWidget* parent, const QString& description, bool begin);
 	
-	//the following functions return a single html table (needed for html file export and printing)
-	static QString singleSubgroupsTimetableDaysHorizontalHtml(int htmlLevel, int subgroup, const QString& saveTime, bool printActivityTags, bool repeatNames);
-	static QString singleSubgroupsTimetableDaysVerticalHtml(int htmlLevel, int subgroup, const QString& saveTime, bool printActivityTags, bool repeatNames);
-	static QString singleSubgroupsTimetableTimeHorizontalHtml(int htmlLevel, int maxSubgroups, QSet<int>& excludedNames, const QString& saveTime, bool printActivityTags, bool repeatNames);
-	static QString singleSubgroupsTimetableTimeVerticalHtml(int htmlLevel, int maxSubgroups, QSet<int>& excludedNames, const QString& saveTime, bool printActivityTags, bool repeatNames);
-	static QString singleSubgroupsTimetableTimeHorizontalDailyHtml(int htmlLevel, int day, int maxSubgroups, QSet<int>& excludedNames, const QString& saveTime, bool printActivityTags, bool repeatNames);
-	static QString singleSubgroupsTimetableTimeVerticalDailyHtml(int htmlLevel, int day, int maxSubgroups, QSet<int>& excludedNames, const QString& saveTime, bool printActivityTags, bool repeatNames);
+	//the following functions return a single HTML table (needed for HTML file export and printing)
+	static QString singleSubgroupsTimetableDaysHorizontalHtml(int htmlLevel, int subgroup, const QString& saveTime, bool printActivityTags, bool repeatNames, const QList<int>& subgroupsSortedOrder=QList<int>());
+	static QString singleSubgroupsTimetableDaysVerticalHtml(int htmlLevel, int subgroup, const QString& saveTime, bool printActivityTags, bool repeatNames, const QList<int>& subgroupsSortedOrder=QList<int>());
+	static QString singleSubgroupsTimetableTimeHorizontalHtml(int htmlLevel, int maxSubgroups, QSet<int>& excludedNames, const QString& saveTime, bool printActivityTags, bool repeatNames, const QList<int>& subgroupsSortedOrder=QList<int>());
+	static QString singleSubgroupsTimetableTimeVerticalHtml(int htmlLevel, int maxSubgroups, QSet<int>& excludedNames, const QString& saveTime, bool printActivityTags, bool repeatNames, const QList<int>& subgroupsSortedOrder=QList<int>());
+	static QString singleSubgroupsTimetableTimeHorizontalDailyHtml(int htmlLevel, int day, int maxSubgroups, QSet<int>& excludedNames, const QString& saveTime, bool printActivityTags, bool repeatNames, const QList<int>& subgroupsSortedOrder=QList<int>());
+	static QString singleSubgroupsTimetableTimeVerticalDailyHtml(int htmlLevel, int day, int maxSubgroups, QSet<int>& excludedNames, const QString& saveTime, bool printActivityTags, bool repeatNames, const QList<int>& subgroupsSortedOrder=QList<int>());
 	static QString singleGroupsTimetableDaysHorizontalHtml(int htmlLevel, int group, const QString& saveTime, bool printActivityTags, bool detailed, bool repeatNames);
 	static QString singleGroupsTimetableDaysVerticalHtml(int htmlLevel, int group, const QString& saveTime, bool printActivityTags, bool detailed, bool repeatNames);
 	static QString singleGroupsTimetableTimeHorizontalHtml(int htmlLevel, int maxGroups, QSet<int>& excludedNames, const QString& saveTime, bool printActivityTags, bool detailed, bool repeatNames);
@@ -124,32 +126,32 @@ public:
 	static void computeHashActivityColorBySubjectAndStudents();
 
 private:
-	//this function must be called before export html files, because it compute the IDs
+	//this function must be called before export HTML files, because it compute the IDs
 	static void computeHashForIDsTimetable();
 
-	//this function must be called before export html files, because it is needed for the allActivities tables
+	//this function must be called before export HTML files, because it is needed for the allActivities tables
 	static void computeActivitiesAtTime();
 	
-	//this function must be called before export html files, because it is needed to add activities with same starting time (simultaneous activities)
+	//this function must be called before export HTML files, because it is needed to add activities with same starting time (simultaneous activities)
 	static void computeActivitiesWithSameStartingTime();
 	//this function add activities with same starting time into the allActivities list
 	static bool addActivitiesWithSameStartingTime(QList<int>& allActivities, int hour);
 
-	//the following functions write the conflicts text and the xml files
-	static void writeSubgroupsTimetableXml(QWidget* parent, const QString& xmlfilename);
+	//the following functions write the conflicts as text and the XML files
+	static void writeSubgroupsTimetableXml(QWidget* parent, const QString& xmlfilename, const QList<int>& subgroupsSortedOrder=QList<int>());
 	static void writeTeachersTimetableXml(QWidget* parent, const QString& xmlfilename);
 	static void writeActivitiesTimetableXml(QWidget* parent, const QString& xmlfilename);
 	static void writeConflictsTxt(QWidget* parent, const QString& filename, const QString& saveTime, int placedActivities);
 
-	//the following functions write the css and html timetable files
+	//the following functions write the CSS and HTML timetable files
 	static void writeIndexHtml(QWidget* parent, const QString& htmlfilename, const QString& saveTime, int placedActivities);
 	static void writeStylesheetCss(QWidget* parent, const QString& cssfilename, const QString& saveTime, int placedActivities);
-	static void writeSubgroupsTimetableDaysHorizontalHtml(QWidget* parent, const QString& htmlfilename, const QString& saveTime, int placedActivities);
-	static void writeSubgroupsTimetableDaysVerticalHtml(QWidget* parent, const QString& htmlfilename, const QString& saveTime, int placedActivities);
-	static void writeSubgroupsTimetableTimeHorizontalHtml(QWidget* parent, const QString& htmlfilename, const QString& saveTime, int placedActivities);
-	static void writeSubgroupsTimetableTimeVerticalHtml(QWidget* parent, const QString& htmlfilename, const QString& saveTime, int placedActivities);
-	static void writeSubgroupsTimetableTimeHorizontalDailyHtml(QWidget* parent, const QString& htmlfilename, const QString& saveTime, int placedActivities);
-	static void writeSubgroupsTimetableTimeVerticalDailyHtml(QWidget* parent, const QString& htmlfilename, const QString& saveTime, int placedActivities);
+	static void writeSubgroupsTimetableDaysHorizontalHtml(QWidget* parent, const QString& htmlfilename, const QString& saveTime, int placedActivities, const QList<int>& subgroupsSortedOrder=QList<int>());
+	static void writeSubgroupsTimetableDaysVerticalHtml(QWidget* parent, const QString& htmlfilename, const QString& saveTime, int placedActivities, const QList<int>& subgroupsSortedOrder=QList<int>());
+	static void writeSubgroupsTimetableTimeHorizontalHtml(QWidget* parent, const QString& htmlfilename, const QString& saveTime, int placedActivities, const QList<int>& subgroupsSortedOrder=QList<int>());
+	static void writeSubgroupsTimetableTimeVerticalHtml(QWidget* parent, const QString& htmlfilename, const QString& saveTime, int placedActivities, const QList<int>& subgroupsSortedOrder=QList<int>());
+	static void writeSubgroupsTimetableTimeHorizontalDailyHtml(QWidget* parent, const QString& htmlfilename, const QString& saveTime, int placedActivities, const QList<int>& subgroupsSortedOrder=QList<int>());
+	static void writeSubgroupsTimetableTimeVerticalDailyHtml(QWidget* parent, const QString& htmlfilename, const QString& saveTime, int placedActivities, const QList<int>& subgroupsSortedOrder=QList<int>());
 	static void writeGroupsTimetableDaysHorizontalHtml(QWidget* parent, const QString& htmlfilename, const QString& saveTime, int placedActivities);
 	static void writeGroupsTimetableDaysVerticalHtml(QWidget* parent, const QString& htmlfilename, const QString& saveTime, int placedActivities);
 	static void writeGroupsTimetableTimeHorizontalHtml(QWidget* parent, const QString& htmlfilename, const QString& saveTime, int placedActivities);
@@ -198,11 +200,11 @@ private:
 	static void writeStudentsStatisticsHtml(QWidget* parent, const QString& htmlfilename, const QString& saveTime, int placedActivities);
 
 	//the following functions return QStrings, because they are 'only' subfunctions to the writeXxxHtml functions
-	static QString writeActivityStudents(int htmlLevel, int ai, int day, int hour, bool notAvailable, bool colspan, bool rowspan, bool printActivityTags, QString skipStudentsSet);
+	static QString writeActivityStudents(int htmlLevel, int ai, int day, int hour, bool notAvailable, bool colspan, bool rowspan, bool printActivityTags, const QString& skipStudentsSet);
 	static QString writeActivitiesStudents(int htmlLevel, const QList<int>& allActivities, bool printActivityTags);
-	static QString writeActivityTeacher(int htmlLevel, int teacher, int day, int hour, bool colspan, bool rowspan, bool printActivityTags, QString skipTeacher);
+	static QString writeActivityTeacher(int htmlLevel, int teacher, int day, int hour, bool colspan, bool rowspan, bool printActivityTags, const QString& skipTeacher);
 	static QString writeActivitiesTeachers(int htmlLevel, const QList<int>& allActivities, bool printActivityTags);
-	static QString writeActivityRoom(int htmlLevel, int room, int day, int hour, bool colspan, bool rowspan, bool printActivityTags/*, QString skipRoom*/); //currently unneeded, because FET supports only one room per activity
+	static QString writeActivityRoom(int htmlLevel, int room, int day, int hour, bool colspan, bool rowspan, bool printActivityTags/*, const QString& skipRoom*/); //currently unneeded, because FET supports only one room per activity
 	static QString writeActivitiesRooms(int htmlLevel, const QList<int>& allActivities, bool printActivityTags);
 	static QString writeActivitiesSubjects(int htmlLevel, const QList<int>& allActivities, bool printActivityTags);
 	static QString writeActivitiesActivityTags(int htmlLevel, const QList<int>& allActivities, bool printActivityTags);
