@@ -64,6 +64,11 @@ ActivitiesForm::ActivitiesForm(QWidget* parent, const QString& teacherName, cons
 	if(settings.contains(this->metaObject()->className()+QString("/splitter-state")))
 		splitter->restoreState(settings.value(this->metaObject()->className()+QString("/splitter-state")).toByteArray());
 	showRelatedCheckBox->setChecked(settings.value(this->metaObject()->className()+QString("/show-related-check-box-state"), "false").toBool());
+
+	/*invertedTeacherCheckBox->setChecked(settings.value(this->metaObject()->className()+QString("/inverted-teacher-check-box-state"), "false").toBool());
+	invertedStudentsCheckBox->setChecked(settings.value(this->metaObject()->className()+QString("/inverted-students-check-box-state"), "false").toBool());
+	invertedSubjectCheckBox->setChecked(settings.value(this->metaObject()->className()+QString("/inverted-subject-check-box-state"), "false").toBool());
+	invertedActivityTagCheckBox->setChecked(settings.value(this->metaObject()->className()+QString("/inverted-activity-tag-check-box-state"), "false").toBool());*/
 	
 	connect(activitiesListWidget, SIGNAL(currentRowChanged(int)), this, SLOT(activityChanged()));
 	connect(addActivityPushButton, SIGNAL(clicked()), this, SLOT(addActivity()));
@@ -76,6 +81,16 @@ ActivitiesForm::ActivitiesForm(QWidget* parent, const QString& teacherName, cons
 	connect(helpPushButton, SIGNAL(clicked()), this, SLOT(help()));
 	connect(commentsPushButton, SIGNAL(clicked()), this, SLOT(activityComments()));
 
+	invertedTeacherCheckBox->setChecked(false);
+	invertedStudentsCheckBox->setChecked(false);
+	invertedSubjectCheckBox->setChecked(false);
+	invertedActivityTagCheckBox->setChecked(false);
+
+	connect(invertedTeacherCheckBox, SIGNAL(toggled(bool)), this, SLOT(filterChanged()));
+	connect(invertedStudentsCheckBox, SIGNAL(toggled(bool)), this, SLOT(studentsFilterChanged()));
+	connect(invertedSubjectCheckBox, SIGNAL(toggled(bool)), this, SLOT(filterChanged()));
+	connect(invertedActivityTagCheckBox, SIGNAL(toggled(bool)), this, SLOT(filterChanged()));
+
 	QSize tmp1=teachersComboBox->minimumSizeHint();
 	Q_UNUSED(tmp1);
 	QSize tmp2=studentsComboBox->minimumSizeHint();
@@ -159,6 +174,11 @@ ActivitiesForm::~ActivitiesForm()
 	settings.setValue(this->metaObject()->className()+QString("/splitter-state"), splitter->saveState());
 
 	settings.setValue(this->metaObject()->className()+QString("/show-related-check-box-state"), showRelatedCheckBox->isChecked());
+
+	/*settings.setValue(this->metaObject()->className()+QString("/inverted-teacher-check-box-state"), invertedTeacherCheckBox->isChecked());
+	settings.setValue(this->metaObject()->className()+QString("/inverted-students-check-box-state"), invertedStudentsCheckBox->isChecked());
+	settings.setValue(this->metaObject()->className()+QString("/inverted-subject-check-box-state"), invertedSubjectCheckBox->isChecked());
+	settings.setValue(this->metaObject()->className()+QString("/inverted-activity-tag-check-box-state"), invertedActivityTagCheckBox->isChecked());*/
 }
 
 bool ActivitiesForm::filterOk(Activity* act)
@@ -177,18 +197,46 @@ bool ActivitiesForm::filterOk(Activity* act)
 				ok2=true;
 				break;
 			}
+		
+		if(invertedTeacherCheckBox->isChecked())
+			ok2=!ok2;
+		
 		if(!ok2)
 			ok=false;
 	}
+	else{
+		if(invertedTeacherCheckBox->isChecked() && act->teachersNames.count()>0)
+			ok=false;
+	}
 
 	//subject
-	if(sbn!="" && sbn!=act->subjectName)
-		ok=false;
-		
+	if(!invertedSubjectCheckBox->isChecked()){
+		if(sbn!="" && sbn!=act->subjectName)
+			ok=false;
+	}
+	else{
+		if(sbn=="")
+			ok=false;
+		else if(sbn==act->subjectName)
+			ok=false;
+	}
+	
 	//activity tag
-	if(atn!="" && !act->activityTagsNames.contains(atn))
-		ok=false;
-		
+	if(!invertedActivityTagCheckBox->isChecked()){
+		if(atn!="" && !act->activityTagsNames.contains(atn))
+			ok=false;
+	}
+	else{
+		if(atn!=""){
+			if(act->activityTagsNames.contains(atn))
+				ok=false;
+		}
+		else{
+			if(act->activityTagsNames.count()>0)
+				ok=false;
+		}
+	}
+	
 	//students
 	if(stn!=""){
 		bool ok2=false;
@@ -198,12 +246,19 @@ bool ActivitiesForm::filterOk(Activity* act)
 				ok2=true;
 				break;
 			}
+
+		if(invertedStudentsCheckBox->isChecked())
+			ok2=!ok2;
+
 		if(!ok2)
 			ok=false;
 	}
 	else{
 		assert(showedStudents.count()==1);
 		assert(showedStudents.contains(""));
+
+		if(invertedStudentsCheckBox->isChecked() && act->studentsNames.count()>0)
+			ok=false;
 	}
 	
 	return ok;
@@ -223,10 +278,10 @@ void ActivitiesForm::studentsFilterChanged()
 			showedStudents.insert("");
 		else{
 			//down
-			StudentsSet* set=gt.rules.searchStudentsSet(studentsComboBox->currentText());
-			assert(set!=NULL);
-			if(set->type==STUDENTS_YEAR){
-				StudentsYear* year=(StudentsYear*)set;
+			StudentsSet* studentsSet=gt.rules.searchStudentsSet(studentsComboBox->currentText());
+			assert(studentsSet!=nullptr);
+			if(studentsSet->type==STUDENTS_YEAR){
+				StudentsYear* year=(StudentsYear*)studentsSet;
 				showedStudents.insert(year->name);
 				for(StudentsGroup* group : qAsConst(year->groupsList)){
 					showedStudents.insert(group->name);
@@ -234,14 +289,14 @@ void ActivitiesForm::studentsFilterChanged()
 						showedStudents.insert(subgroup->name);
 				}
 			}
-			else if(set->type==STUDENTS_GROUP){
-				StudentsGroup* group=(StudentsGroup*) set;
+			else if(studentsSet->type==STUDENTS_GROUP){
+				StudentsGroup* group=(StudentsGroup*)studentsSet;
 				showedStudents.insert(group->name);
 				for(StudentsSubgroup* subgroup : qAsConst(group->subgroupsList))
 					showedStudents.insert(subgroup->name);
 			}
-			else if(set->type==STUDENTS_SUBGROUP){
-				StudentsSubgroup* subgroup=(StudentsSubgroup*) set;
+			else if(studentsSet->type==STUDENTS_SUBGROUP){
+				StudentsSubgroup* subgroup=(StudentsSubgroup*)studentsSet;
 				showedStudents.insert(subgroup->name);
 			}
 			else
@@ -270,7 +325,7 @@ void ActivitiesForm::studentsFilterChanged()
 
 void ActivitiesForm::filterChanged()
 {
-	int nacts=0, nsubacts=0, nh=0;
+	int /*nacts=0,*/ nsubacts=0, nh=0;
 	int ninact=0, ninacth=0;
 
 	QString s;
@@ -289,8 +344,8 @@ void ActivitiesForm::filterChanged()
 			if(USE_GUI_COLORS && !act->active)
 				activitiesListWidget->item(k-1)->setBackground(activitiesListWidget->palette().alternateBase());
 			
-			if(act->id==act->activityGroupId || act->activityGroupId==0)
-				nacts++;
+			//if(act->id==act->activityGroupId || act->activityGroupId==0)
+			//	nacts++;
 			nsubacts++;
 			
 			nh+=act->duration;
@@ -354,7 +409,7 @@ void ActivitiesForm::modifyActivity()
 	int valh=activitiesListWidget->horizontalScrollBar()->value();
 
 	Activity* act=visibleActivitiesList[ind];
-	assert(act!=NULL);
+	assert(act!=nullptr);
 	
 	QStringList teachers=act->teachersNames;
 	bool diffTeachers=false;
@@ -424,9 +479,13 @@ void ActivitiesForm::modifyActivity()
 			s2+="\n\n";
 			s2+=tr("The fields which are different are: %1").arg(s.join(", "));
 				
-			int t=QMessageBox::warning(this, tr("FET warning"), s2, tr("Abort"), tr("Continue"), QString(), 1, 0);
+			/*int t=QMessageBox::warning(this, tr("FET warning"), s2, tr("Abort"), tr("Continue"), QString(), 1, 0);
 			
 			if(t==0)
+				return;*/
+			QMessageBox::StandardButton t=QMessageBox::warning(this, tr("FET warning"), s2, QMessageBox::Ok | QMessageBox::Cancel);
+			
+			if(t==QMessageBox::Cancel)
 				return;
 		}
 	}
@@ -466,7 +525,7 @@ void ActivitiesForm::removeActivity()
 	int valh=activitiesListWidget->horizontalScrollBar()->value();
 
 	Activity* act=visibleActivitiesList[ind];
-	assert(act!=NULL);
+	assert(act!=nullptr);
 
 	QString s;
 	s=tr("Remove activity?");
@@ -478,7 +537,7 @@ void ActivitiesForm::removeActivity()
 	s+="\n";
 
 	switch( LongTextMessageBox::confirmation( this, tr("FET confirmation"),
-	s, tr("Yes"), tr("No"), 0, 0, 1 ) ){
+	s, tr("Yes"), tr("No"), QString(), 0, 1 ) ){
 	case 0: // The user clicked the OK button or pressed Enter
 		gt.rules.removeActivity(act->id, act->activityGroupId);
 		PlanningChanged::increasePlanningCommunicationSpinBox();
@@ -513,7 +572,7 @@ void ActivitiesForm::activityChanged()
 	QString s;
 	Activity* act=visibleActivitiesList[index];
 
-	assert(act!=NULL);
+	assert(act!=nullptr);
 	s=act->getDetailedDescriptionWithConstraints(gt.rules);
 	activityTextEdit->setPlainText(s);
 }
@@ -554,6 +613,9 @@ void ActivitiesForm::help()
 	s+=tr("Show related: if you select this, there will be listed activities for groups and subgroups contained also in the current set (if the current set"
 		" is a year or a group) and also higher ranked year or group (if the current set is a group or a subgroup).");
 	
+	s+="\n\n";
+	s+=tr("Inverted: this will show all the activities which _don't_ respect the selected filter.");
+	
 	LongTextMessageBox::largeInformation(this, tr("FET Help"), s);
 }
 
@@ -568,7 +630,7 @@ void ActivitiesForm::activityComments()
 	assert(ind<visibleActivitiesList.count());
 
 	Activity* act=visibleActivitiesList[ind];
-	assert(act!=NULL);
+	assert(act!=nullptr);
 
 	QDialog getCommentsDialog(this);
 	
