@@ -141,9 +141,13 @@ void ActivityTagsForm::removeActivityTag()
 		return;
 	}
 
+	/*if(QMessageBox::warning( this, tr("FET"),
+		tr("Are you sure you want to delete this activity tag?"),
+		tr("Yes"), tr("No"), QString(), 0, 1 ) == 1)
+		return;*/
 	if(QMessageBox::warning( this, tr("FET"),
 		tr("Are you sure you want to delete this activity tag?"),
-		tr("Yes"), tr("No"), 0, 0, 1 ) == 1)
+		QMessageBox::Yes | QMessageBox::No) == QMessageBox::No)
 		return;
 
 	int tmp=gt.rules.removeActivityTag(text);
@@ -311,7 +315,7 @@ void ActivityTagsForm::deactivateActivityTag()
 
 	QString text=activityTagsListWidget->currentItem()->text();
 	int count=gt.rules.deactivateActivityTag(text);
-	QMessageBox::information(this, tr("FET information"), tr("De-activated a number of %1 activities").arg(count));
+	QMessageBox::information(this, tr("FET information"), tr("Deactivated a number of %1 activities").arg(count));
 }
 
 void ActivityTagsForm::printableActivityTag()
@@ -359,7 +363,7 @@ void ActivityTagsForm::comments()
 	}
 	
 	ActivityTag* at=gt.rules.activityTagsList[ind];
-	assert(at!=NULL);
+	assert(at!=nullptr);
 
 	QDialog getCommentsDialog(this);
 	
