@@ -68,6 +68,8 @@ AddActivityForm::AddActivityForm(QWidget* parent, const QString& teacherName, co
 {
 	setupUi(this);
 
+	studentsSeparatelyCheckBox->setChecked(false);
+
 	for(Teacher* tch : qAsConst(gt.rules.teachersList))
 		teacherNamesSet.insert(tch->name);
 	for(Subject* sbj : qAsConst(gt.rules.subjectsList))
@@ -82,84 +84,14 @@ AddActivityForm::AddActivityForm(QWidget* parent, const QString& teacherName, co
 	allActivityTagsListWidget->setSelectionMode(QAbstractItemView::SingleSelection);
 	selectedActivityTagsListWidget->setSelectionMode(QAbstractItemView::SingleSelection);
 
+	splitSpinBox->setMinimum(1);
 	splitSpinBox->setMaximum(MAX_SPLIT_OF_AN_ACTIVITY);
-
-	durList.clear();
-	durList.append(duration1SpinBox);
-	durList.append(duration2SpinBox);
-	durList.append(duration3SpinBox);
-	durList.append(duration4SpinBox);
-	durList.append(duration5SpinBox);
-	durList.append(duration6SpinBox);
-	durList.append(duration7SpinBox);
-	durList.append(duration8SpinBox);
-	durList.append(duration9SpinBox);
-	durList.append(duration10SpinBox);
-	durList.append(duration11SpinBox);
-	durList.append(duration12SpinBox);
-	durList.append(duration13SpinBox);
-	durList.append(duration14SpinBox);
-	durList.append(duration15SpinBox);
-	durList.append(duration16SpinBox);
-	durList.append(duration17SpinBox);
-	durList.append(duration18SpinBox);
-	durList.append(duration19SpinBox);
-	durList.append(duration20SpinBox);
-	durList.append(duration21SpinBox);
-	durList.append(duration22SpinBox);
-	durList.append(duration23SpinBox);
-	durList.append(duration24SpinBox);
-	durList.append(duration25SpinBox);
-	durList.append(duration26SpinBox);
-	durList.append(duration27SpinBox);
-	durList.append(duration28SpinBox);
-	durList.append(duration29SpinBox);
-	durList.append(duration30SpinBox);
-	durList.append(duration31SpinBox);
-	durList.append(duration32SpinBox);
-	durList.append(duration33SpinBox);
-	durList.append(duration34SpinBox);
-	durList.append(duration35SpinBox);
+	splitSpinBox->setValue(1);
 	
-	for(int i=0; i<MAX_SPLIT_OF_AN_ACTIVITY; i++)
-		dur(i)->setMaximum(gt.rules.nHoursPerDay);
-
+	durList.clear();
 	activList.clear();
-	activList.append(active1CheckBox);
-	activList.append(active2CheckBox);
-	activList.append(active3CheckBox);
-	activList.append(active4CheckBox);
-	activList.append(active5CheckBox);
-	activList.append(active6CheckBox);
-	activList.append(active7CheckBox);
-	activList.append(active8CheckBox);
-	activList.append(active9CheckBox);
-	activList.append(active10CheckBox);
-	activList.append(active11CheckBox);
-	activList.append(active12CheckBox);
-	activList.append(active13CheckBox);
-	activList.append(active14CheckBox);
-	activList.append(active15CheckBox);
-	activList.append(active16CheckBox);
-	activList.append(active17CheckBox);
-	activList.append(active18CheckBox);
-	activList.append(active19CheckBox);
-	activList.append(active20CheckBox);
-	activList.append(active21CheckBox);
-	activList.append(active22CheckBox);
-	activList.append(active23CheckBox);
-	activList.append(active24CheckBox);
-	activList.append(active25CheckBox);
-	activList.append(active26CheckBox);
-	activList.append(active27CheckBox);
-	activList.append(active28CheckBox);
-	activList.append(active29CheckBox);
-	activList.append(active30CheckBox);
-	activList.append(active31CheckBox);
-	activList.append(active32CheckBox);
-	activList.append(active33CheckBox);
-	activList.append(active34CheckBox);
-	activList.append(active35CheckBox);
+
+	populateSubactivitiesTabWidget(splitSpinBox->value());
 
 	QSettings settings(COMPANY, PROGRAM);
 
@@ -191,8 +123,6 @@ AddActivityForm::AddActivityForm(QWidget* parent, const QString& teacherName, co
 	connect(clearStudentsPushButton, SIGNAL(clicked()), this, SLOT(clearStudents()));
 	connect(clearTeacherPushButton, SIGNAL(clicked()), this, SLOT(clearTeachers()));
 
-	connect(minDayDistanceSpinBox, SIGNAL(valueChanged(int)), this, SLOT(minDaysChanged()));
-	
 	centerWidgetOnScreen(this);
 	restoreFETDialogGeometry(this);
 	
@@ -233,25 +163,27 @@ AddActivityForm::AddActivityForm(QWidget* parent, const QString& teacherName, co
 	updateAllTeachersListWidget();
 	selectedTeachersListWidget->clear();
 
-	minDayDistanceSpinBox->setMaximum(gt.rules.nDaysPerWeek);
-	minDayDistanceSpinBox->setMinimum(0);
-	minDayDistanceSpinBox->setValue(1);
+	if(gt.rules.mode!=MORNINGS_AFTERNOONS)
+		minDaysDistanceSpinBox->setMaximum(gt.rules.nDaysPerWeek-1);
+	else
+		minDaysDistanceSpinBox->setMaximum(gt.rules.nDaysPerWeek/2-1);
+	minDaysDistanceSpinBox->setMinimum(0);
+	minDaysDistanceSpinBox->setValue(1);
+	
+	connect(minDaysDistanceSpinBox, SIGNAL(valueChanged(int)), this, SLOT(minDaysChanged()));
 	
 	int nSplit=splitSpinBox->value();
-	for(int i=0; i<MAX_SPLIT_OF_AN_ACTIVITY; i++){
-		if(i<nSplit)
-			subactivitiesTabWidget->setTabEnabled(i, true);
-		else
-			subactivitiesTabWidget->setTabEnabled(i, false);
-	}
+
+	halfCheckBox->setChecked(false);
+	halfCheckBox->setEnabled(nSplit>=2 && gt.rules.mode==MORNINGS_AFTERNOONS);
+	minDaysDistanceTextLabel->setEnabled(nSplit>=2);
+	minDaysDistanceSpinBox->setEnabled(nSplit>=2);
+	percentageTextLabel->setEnabled(nSplit>=2 && minDaysDistanceSpinBox->value()>0);
+	percentageLineEdit->setEnabled(nSplit>=2 && minDaysDistanceSpinBox->value()>0);
+	forceConsecutiveCheckBox->setChecked(true);
+	forceConsecutiveCheckBox->setEnabled(nSplit>=2 && minDaysDistanceSpinBox->value()>0);
 	
-	minDayDistanceTextLabel->setEnabled(nSplit>=2);
-	minDayDistanceSpinBox->setEnabled(nSplit>=2);
-	percentageTextLabel->setEnabled(nSplit>=2 && minDayDistanceSpinBox->value()>0);
-	percentageLineEdit->setEnabled(nSplit>=2 && minDayDistanceSpinBox->value()>0);
-	forceConsecutiveCheckBox->setEnabled(nSplit>=2 && minDayDistanceSpinBox->value()>0);
-	
-	subactivitiesTabWidget->setCurrentIndex(0);
+	connect(halfCheckBox, SIGNAL(toggled(bool)), this, SLOT(halfCheckBoxToggled()));
 	
 	nStudentsSpinBox->setMinimum(-1);
 	nStudentsSpinBox->setMaximum(MAX_ROOM_CAPACITY);
@@ -282,6 +214,61 @@ AddActivityForm::~AddActivityForm()
 	settings.setValue(this->metaObject()->className()+QString("/all-teachers-radio-button-state"), allTeachersRadioButton->isChecked());
 }
 
+void AddActivityForm::populateSubactivitiesTabWidget(int n)
+{
+	int oldIndex=subactivitiesTabWidget->currentIndex();
+
+	int oldN=subactivitiesTabWidget->count();
+	if(oldN>n){
+		for(int i=oldN-1; i>=n; i--){
+			QWidget* wd=subactivitiesTabWidget->widget(i);
+			subactivitiesTabWidget->removeTab(i);
+			assert(durList.count()>0);
+			durList.removeLast();
+			assert(activList.count()>0);
+			activList.removeLast();
+			delete wd;
+		}
+
+		if(oldIndex<subactivitiesTabWidget->count())
+			subactivitiesTabWidget->setCurrentIndex(oldIndex);
+		else
+			subactivitiesTabWidget->setCurrentIndex(subactivitiesTabWidget->count()-1);
+	}
+	else if(oldN<n){
+		for(int i=oldN; i<n; i++){
+			QWidget* wd=new QWidget(subactivitiesTabWidget);
+			
+			QCheckBox* cb=new QCheckBox(tr("Active"), wd);
+			cb->setChecked(true);
+			QSpinBox* sb=new QSpinBox(wd);
+			sb->setMinimum(1);
+			sb->setMaximum(MAX_HOURS_PER_DAY);
+			sb->setValue(1);
+			QLabel* ld=new QLabel(tr("Duration"), wd);
+			
+			QHBoxLayout* hld=new QHBoxLayout();
+			hld->addWidget(ld);
+			hld->addWidget(sb);
+			
+			QHBoxLayout* hla=new QHBoxLayout();
+			hla->addStretch();
+			hla->addWidget(cb);
+			
+			QVBoxLayout* vl=new QVBoxLayout(wd);
+			vl->addLayout(hld);
+			vl->addLayout(hla);
+			
+			subactivitiesTabWidget->addTab(wd, QString::number(i+1));
+			
+			durList.append(sb);
+			activList.append(cb);
+		}
+
+		subactivitiesTabWidget->setCurrentIndex(subactivitiesTabWidget->count()-1);
+	}
+}
+
 void AddActivityForm::allTeachersRadioButtonToggled(bool toggled)
 {
 	if(toggled)
@@ -484,17 +471,14 @@ void AddActivityForm::splitChanged()
 {
 	int nSplit=splitSpinBox->value();
 	
-	minDayDistanceTextLabel->setEnabled(nSplit>=2);
-	minDayDistanceSpinBox->setEnabled(nSplit>=2);
-	percentageTextLabel->setEnabled(nSplit>=2 && minDayDistanceSpinBox->value()>0);
-	percentageLineEdit->setEnabled(nSplit>=2 && minDayDistanceSpinBox->value()>0);
-	forceConsecutiveCheckBox->setEnabled(nSplit>=2 && minDayDistanceSpinBox->value()>0);
+	halfCheckBox->setEnabled(nSplit>=2 && gt.rules.mode==MORNINGS_AFTERNOONS);
+	minDaysDistanceTextLabel->setEnabled(nSplit>=2);
+	minDaysDistanceSpinBox->setEnabled(nSplit>=2);
+	percentageTextLabel->setEnabled(nSplit>=2 && minDaysDistanceSpinBox->value()>0);
+	percentageLineEdit->setEnabled(nSplit>=2 && minDaysDistanceSpinBox->value()>0);
+	forceConsecutiveCheckBox->setEnabled(nSplit>=2 && minDaysDistanceSpinBox->value()>0);
 
-	for(int i=0; i<MAX_SPLIT_OF_AN_ACTIVITY; i++)
-		if(i<nSplit)
-			subactivitiesTabWidget->setTabEnabled(i, true);
-		else
-			subactivitiesTabWidget->setTabEnabled(i, false);
+	populateSubactivitiesTabWidget(nSplit);
 }
 
 SecondMinDaysDialog::SecondMinDaysDialog(QWidget* p, int minD, double w) :QDialog(p)
@@ -513,7 +497,7 @@ SecondMinDaysDialog::SecondMinDaysDialog(QWidget* p, int minD, double w) :QDialo
 	  "too tight, but you can remove the second constraint at any time).").arg(minD-1);
 	l+="\n\n";
 	l+=tr("Note: 95% is usually enough for min days constraints referring to same activities. "
-	  "The weights are cumulated if referring to the same activities. If you have 2 constraints with say 95%"
+	  "The weights are accumulated if referring to the same activities. If you have 2 constraints with say 95%"
 	  " (say min n days and min n-1 days), "
 	  "the min n days constraint is skipped with probability 5%, then min n-1 days constraint is skipped with "
 	  "probability 0.25%=5%*5%, so you'll get in 99.75% cases the min n-1 days constraint respected.");
@@ -613,6 +597,11 @@ void SecondMinDaysDialog::yesPressed()
 
 void AddActivityForm::addActivity()
 {
+	if(studentsSeparatelyCheckBox->isChecked()){
+		addMultipleActivities();
+		return;
+	}
+
 	double weight;
 	QString tmp=percentageLineEdit->text();
 	weight_sscanf(tmp, "%lf", &weight);
@@ -677,7 +666,7 @@ void AddActivityForm::addActivity()
 	}
 	else{
 		for(int i=0; i<selectedStudentsListWidget->count(); i++){
-			//assert(gt.rules.searchStudentsSet(selectedStudentsListWidget->item(i)->text())!=NULL);
+			//assert(gt.rules.searchStudentsSet(selectedStudentsListWidget->item(i)->text())!=nullptr);
 			/*assert(numberOfStudentsHash.contains(selectedStudentsListWidget->item(i)->text()));
 			numberOfStudents+=numberOfStudentsHash.value(selectedStudentsListWidget->item(i)->text());*/
 			assert(gt.rules.permanentStudentsHash.contains(selectedStudentsListWidget->item(i)->text()));
@@ -690,7 +679,7 @@ void AddActivityForm::addActivity()
 	}
 
 	if(splitSpinBox->value()==1){ //indivisible activity
-		int duration=duration1SpinBox->value();
+		int duration=dur(0)->value();
 		if(duration<0){
 			QMessageBox::warning(this, tr("FET information"),
 				tr("Invalid duration"));
@@ -698,7 +687,7 @@ void AddActivityForm::addActivity()
 		}
 
 		bool active=false;
-		if(active1CheckBox->isChecked())
+		if(activ(0)->isChecked())
 			active=true;
 
 		int activityid=0; //We set the id of this newly added activity = (the largest existing id + 1)
@@ -719,14 +708,18 @@ void AddActivityForm::addActivity()
 		}
 
 		if(already_existing){
-			int t=QMessageBox::question(this, tr("FET question"),
-				//tr("This activity already exists. Insert it again?"),
+			/*int t=QMessageBox::question(this, tr("FET question"),
 				tr("A similar activity already exists. Do you want to insert current activity?"),
 				tr("Yes"),tr("No"));
-			assert(t==0 || t==1 ||t==-1);
+			assert(t==0 || t==1 || t==-1);
 			if(t==1) //no pressed
 				return;
 			if(t==-1) //Esc pressed
+				return;*/
+			QMessageBox::StandardButton t=QMessageBox::question(this, tr("FET question"),
+				tr("A similar activity already exists. Do you want to insert current activity?"),
+				QMessageBox::Yes | QMessageBox::No);
+			if(t==QMessageBox::No)
 				return;
 		}
 
@@ -739,41 +732,95 @@ void AddActivityForm::addActivity()
 			QMessageBox::critical(this, tr("FET information"), tr("Activity NOT added - please report error"));
 	}
 	else{ //split activity
-		if(minDayDistanceSpinBox->value()>0 && splitSpinBox->value()>gt.rules.nDaysPerWeek){
-			int t=LongTextMessageBox::largeConfirmation(this, tr("FET confirmation"),
-			 tr("Possible incorrect setting. Are you sure you want to add current activity? See details below:")+"\n\n"+
-			 tr("You want to add a container activity split into more than the number of days per week and also add a constraint min days between activities."
-			  " This is a very bad practice from the way the algorithm of generation works (it slows down the generation and makes it harder to find a solution).")+
-			 "\n\n"+
-			 tr("The best way to add the activities would be:")+
-			 "\n\n"+
-			 tr("1. If you add 'force consecutive if same day', then couple extra activities in pairs to obtain a number of activities equal to the number of days per week"
-			  ". Example: 7 activities with duration 1 in a 5 days week, then transform into 5 activities with durations: 2,2,1,1,1 and add a single container activity with these 5 components"
-			  " (possibly raising the weight of added constraint min days between activities up to 100%)")+
-			  "\n\n"+
-			 tr("2. If you don't add 'force consecutive if same day', then add a larger activity split into a number of"
-			  " activities equal with the number of days per week and the remaining components into other larger split activity."
-			  " For example, suppose you need to add 7 activities with duration 1 in a 5 days week. Add 2 larger container activities,"
-			  " first one split into 5 activities with duration 1 and second one split into 2 activities with duration 1"
-			  " (possibly raising the weight of added constraints min days between activities for each of the 2 containers up to 100%)")+
-		  	 "\n\n"+
-			 tr("Do you want to add current activities as they are now (not recommended) or cancel and edit them as instructed?")
-			  ,
-			 tr("Yes"), tr("No"), QString(), 0, 1);
+		if(gt.rules.mode!=MORNINGS_AFTERNOONS){
+			if(minDaysDistanceSpinBox->value()>0 && splitSpinBox->value()>gt.rules.nDaysPerWeek){
+				int t=LongTextMessageBox::largeConfirmation(this, tr("FET confirmation"),
+				 tr("Possible incorrect setting. Are you sure you want to add current activity? See details below:")+"\n\n"+
+				 tr("You want to add a container activity split into more than the number of days per week and also add a constraint min days between activities."
+				  " This is a very bad practice from the way the algorithm of generation works (it slows down the generation and makes it harder to find a solution).")+
+				 "\n\n"+
+				 tr("The best way to add the activities would be:")+
+				 "\n\n"+
+				 tr("1. If you add 'force consecutive if same day', then couple extra activities in pairs to obtain a number of activities equal to the number of days per week"
+				  ". Example: 7 activities with duration 1 in a 5 days week, then transform into 5 activities with durations: 2,2,1,1,1 and add a single container activity with these 5 components"
+				  " (possibly raising the weight of added constraint min days between activities up to 100%)")+
+				  "\n\n"+
+				 tr("2. If you don't add 'force consecutive if same day', then add a larger activity split into a number of"
+				  " activities equal with the number of days per week and the remaining components into other larger split activity."
+				  " For example, suppose you need to add 7 activities with duration 1 in a 5 days week. Add 2 larger container activities,"
+				  " first one split into 5 activities with duration 1 and second one split into 2 activities with duration 1"
+				  " (possibly raising the weight of added constraints min days between activities for each of the 2 containers up to 100%)")+
+			  	 "\n\n"+
+				 tr("Do you want to add current activities as they are now (not recommended) or cancel and edit them as instructed?")
+				  ,
+				 tr("Yes"), tr("No"), QString(), 0, 1);
 
-			if(t==1)
-				return;
+				if(t==1)
+					return;
+			}
+		}
+		else{
+			if(!halfCheckBox->isChecked() && minDaysDistanceSpinBox->value()>0 && splitSpinBox->value()>gt.rules.nDaysPerWeek/2){
+				int t=LongTextMessageBox::largeConfirmation(this, tr("FET confirmation"),
+				 tr("Possible incorrect setting. Are you sure you want to add current activity? See details below:")+"\n\n"+
+				 tr("You want to add a container activity split into more than the number of real days per week and also add a constraint min days between activities."
+				  " This is a very bad practice from the way the algorithm of generation works (it slows down the generation and makes it harder to find a solution).")+
+				 "\n\n"+
+				 tr("The best way to add the activities would be:")+
+				 "\n\n"+
+				 tr("1. If you add 'force consecutive if same day', then couple extra activities in pairs to obtain a number of activities equal to the number of real days per week"
+				  ". Example: 7 activities with duration 1 in a 5 real days week, then transform into 5 activities with durations: 2,2,1,1,1 and add a single container activity with these 5 components"
+				  " (possibly raising the weight of added constraint min days between activities up to 100%)")+
+				  "\n\n"+
+				 tr("2. If you don't add 'force consecutive if same day', then add a larger activity split into a number of"
+				  " activities equal with the number of real days per week and the remaining components into other larger split activity."
+				  " For example, suppose you need to add 7 activities with duration 1 in a 5 real days week. Add 2 larger container activities,"
+				  " first one split into 5 activities with duration 1 and second one split into 2 activities with duration 1"
+				  " (possibly raising the weight of added constraints min days between activities for each of the 2 containers up to 100%)")+
+			  	 "\n\n"+
+				 tr("Do you want to add current activities as they are now (not recommended) or cancel and edit them as instructed?")
+				  ,
+				 tr("Yes"), tr("No"), QString(), 0, 1);
+
+				if(t==1)
+					return;
+			}
+			else if(halfCheckBox->isChecked() && minDaysDistanceSpinBox->value()>0 && splitSpinBox->value()>gt.rules.nDaysPerWeek){
+				int t=LongTextMessageBox::largeConfirmation(this, tr("FET confirmation"),
+				 tr("Possible incorrect setting. Are you sure you want to add current activity? See details below:")+"\n\n"+
+				 tr("You want to add a container activity split into more than the number of days per week and also add a constraint min half days between activities."
+				  " This is a very bad practice from the way the algorithm of generation works (it slows down the generation and makes it harder to find a solution).")+
+				 "\n\n"+
+				 tr("The best way to add the activities would be:")+
+				 "\n\n"+
+				 tr("1. If you add 'force consecutive if same day', then couple extra activities in pairs to obtain a number of activities equal to the number of days per week"
+				  ". Example: 12 activities with duration 1 in a 10 days week, then transform into 10 activities with durations: 2,2,1,1,1,1,1,1,1,1 and add a single container"
+				  " activity with these 10 components (possibly raising the weight of added constraint min half days between activities up to 100%)")+
+				  "\n\n"+
+				 tr("2. If you don't add 'force consecutive if same day', then add a larger activity split into a number of"
+				  " activities equal with the number of days per week and the remaining components into other larger split activity."
+				  " For example, suppose you need to add 12 activities with duration 1 in a 10 days week. Add 2 larger container activities,"
+				  " first one split into 10 activities with duration 1 and second one split into 2 activities with duration 1"
+				  " (possibly raising the weight of added constraints min half days between activities for each of the 2 containers up to 100%)")+
+			  	 "\n\n"+
+				 tr("Do you want to add current activities as they are now (not recommended) or cancel and edit them as instructed?")
+				  ,
+				 tr("Yes"), tr("No"), QString(), 0, 1);
+
+				if(t==1)
+					return;
+			}
 		}
 
 		int totalduration;
-		int durations[MAX_SPLIT_OF_AN_ACTIVITY];
-		bool active[MAX_SPLIT_OF_AN_ACTIVITY];
+		QList<int> durations;
+		QList<bool> active;
 		int nsplit=splitSpinBox->value();
 
 		totalduration=0;
 		for(int i=0; i<nsplit; i++){
-			durations[i]=dur(i)->value();
-			active[i]=false;
+			durations.append(dur(i)->value());
+			active.append(false);
 			if(activ(i)->isChecked())
 				active[i]=true;
 
@@ -790,12 +837,12 @@ void AddActivityForm::addActivity()
 		}
 		firstactivityid++;
 
-		int minD=minDayDistanceSpinBox->value();
+		int minD=minDaysDistanceSpinBox->value();
 		bool tmp=gt.rules.addSplitActivityFast(this, firstactivityid, firstactivityid,
 			teachers_names, subject_name, activity_tags_names, students_names,
 			nsplit, totalduration, durations,
 			active, minD, weight, forceConsecutiveCheckBox->isChecked(),
-			(nStudentsSpinBox->value()==-1), nStudentsSpinBox->value(), numberOfStudents);
+			(nStudentsSpinBox->value()==-1), nStudentsSpinBox->value(), numberOfStudents, halfCheckBox->isChecked());
 		if(tmp){
 			if(minD>1 && weight<100.0){
 				SecondMinDaysDialog second(this, minD, weight);
@@ -808,7 +855,12 @@ void AddActivityForm::addActivity()
 					for(int i=0; i<nsplit; i++){
 						acts.append(firstactivityid+i);
 					}
-					TimeConstraint* c=new ConstraintMinDaysBetweenActivities(second.weight, forceConsecutiveCheckBox->isChecked(), nsplit, acts, minD-1);
+
+					TimeConstraint* c;
+					if(!halfCheckBox->isChecked())
+						c=new ConstraintMinDaysBetweenActivities(second.weight, forceConsecutiveCheckBox->isChecked(), nsplit, acts, minD-1);
+					else
+						c=new ConstraintMinHalfDaysBetweenActivities(second.weight, forceConsecutiveCheckBox->isChecked(), nsplit, acts, minD-1);
 					bool tmp=gt.rules.addTimeConstraint(c);
 					assert(tmp);
 				}
@@ -825,6 +877,321 @@ void AddActivityForm::addActivity()
 	PlanningChanged::increasePlanningCommunicationSpinBox();
 }
 
+void AddActivityForm::addMultipleActivities()
+{
+	assert(studentsSeparatelyCheckBox->isChecked());
+
+	double weight;
+	QString tmp=percentageLineEdit->text();
+	weight_sscanf(tmp, "%lf", &weight);
+	if(percentageLineEdit->isEnabled() && (weight<0.0 || weight>100.0)){
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Invalid weight (percentage) for added constraint min days between activities"));
+		return;
+	}
+
+	//subject
+	QString subject_name=subjectsComboBox->currentText();
+	bool found=subjectNamesSet.contains(subject_name);
+	/*int subject_index=gt.rules.searchSubject(subject_name);
+	if(subject_index<0){*/
+	if(!found){
+		QMessageBox::warning(this, tr("FET warning"),
+			tr("Invalid subject"));
+		return;
+	}
+
+	QStringList activity_tags_names;
+	for(int i=0; i<selectedActivityTagsListWidget->count(); i++){
+		//assert(gt.rules.searchActivityTag(selectedActivityTagsListWidget->item(i)->text())>=0);
+		assert(activityTagNamesSet.contains(selectedActivityTagsListWidget->item(i)->text()));
+		activity_tags_names.append(selectedActivityTagsListWidget->item(i)->text());
+	}
+
+	//teachers
+	QStringList teachers_names;
+	if(selectedTeachersListWidget->count()<=0){
+		int t=QMessageBox::question(this, tr("FET question"),
+		 tr("Do you really want to add an activity without teacher(s)?"),
+		 QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes);
+
+		if(t==QMessageBox::No)
+			return;
+	}
+	else{
+		for(int i=0; i<selectedTeachersListWidget->count(); i++){
+			//assert(gt.rules.searchTeacher(selectedTeachersListWidget->item(i)->text())>=0);
+			assert(teacherNamesSet.contains(selectedTeachersListWidget->item(i)->text()));
+			teachers_names.append(selectedTeachersListWidget->item(i)->text());
+		}
+	}
+
+	//students
+	//int numberOfStudents=0;
+	QStringList students_names;
+	if(selectedStudentsListWidget->count()<=1){
+		QMessageBox::warning(this, tr("FET question"),
+		 tr("If you intend to add multiple activities for students (option 'Separately' is checked), please select at least 2 students sets."));
+
+		return;
+	}
+	else{
+		for(int i=0; i<selectedStudentsListWidget->count(); i++){
+			assert(gt.rules.permanentStudentsHash.contains(selectedStudentsListWidget->item(i)->text()));
+			students_names.append(selectedStudentsListWidget->item(i)->text());
+		}
+	}
+
+	if(splitSpinBox->value()==1){ //indivisible activity
+		int duration=dur(0)->value();
+		if(duration<0){
+			QMessageBox::warning(this, tr("FET information"),
+				tr("Invalid duration"));
+			return;
+		}
+
+		bool active=false;
+		if(activ(0)->isChecked())
+			active=true;
+
+		int activityid=0; //We set the id of this newly added activity = (the largest existing id + 1)
+		for(int i=0; i<gt.rules.activitiesList.size(); i++){
+			Activity* act=gt.rules.activitiesList[i];
+			if(act->id > activityid)
+				activityid = act->id;
+		}
+		
+		int cnt_act=0;
+		activityid++;
+
+		for(int st=0; st<students_names.count(); st++){
+			int n1=nStudentsSpinBox->value();
+			int n2;
+			if(n1==-1)
+				n2=gt.rules.permanentStudentsHash.value(students_names.at(st))->numberOfStudents;
+			else
+				n2=nStudentsSpinBox->value();
+			
+			Activity a(gt.rules, activityid, 0, teachers_names, subject_name, activity_tags_names, QStringList(students_names.at(st)),
+				duration, duration, /*parity,*/ active, (nStudentsSpinBox->value()==-1), n1, n2);
+
+			bool already_existing=false;
+			for(int i=0; i<gt.rules.activitiesList.size(); i++){
+				Activity* act=gt.rules.activitiesList[i];
+				if((*act)==a)
+					already_existing=true;
+			}
+	
+			if(already_existing){
+				/*int t=QMessageBox::question(this, tr("FET question"),
+					tr("A similar activity for students set %1 already exists. Do you want to insert current activity?").arg(students_names.at(st)),
+					tr("Yes"),tr("No"));
+				assert(t==0 || t==1 ||t==-1);
+				if(t==1){ //no pressed
+					continue;
+				}
+				if(t==-1){ //Esc pressed
+					continue;
+				}*/
+				
+				QMessageBox::StandardButton t=QMessageBox::question(this, tr("FET question"),
+					tr("A similar activity for students set %1 already exists. Do you want to insert current activity?").arg(students_names.at(st)),
+					QMessageBox::Yes | QMessageBox::No);
+				if(t==QMessageBox::No)
+					return;
+			}
+
+			bool tmp=gt.rules.addSimpleActivityFast(this, activityid, 0, teachers_names, subject_name, activity_tags_names,
+				QStringList(students_names.at(st)), duration, duration, active,
+				(nStudentsSpinBox->value()==-1), n1, n2);
+			if(tmp){
+				cnt_act++;
+				activityid++;
+			}
+		}
+		QMessageBox::information(this, tr("FET information"), tr("%1 activities added").arg(cnt_act));
+	}
+	else{ //split activity
+		if(gt.rules.mode!=MORNINGS_AFTERNOONS){
+			if(minDaysDistanceSpinBox->value()>0 && splitSpinBox->value()>gt.rules.nDaysPerWeek){
+				int t=LongTextMessageBox::largeConfirmation(this, tr("FET confirmation"),
+				 tr("Possible incorrect setting. Are you sure you want to add current activity? See details below:")+"\n\n"+
+				 tr("You want to add a container activity split into more than the number of days per week and also add a constraint min days between activities."
+				  " This is a very bad practice from the way the algorithm of generation works (it slows down the generation and makes it harder to find a solution).")+
+				 "\n\n"+
+				 tr("The best way to add the activities would be:")+
+				 "\n\n"+
+				 tr("1. If you add 'force consecutive if same day', then couple extra activities in pairs to obtain a number of activities equal to the number of days per week"
+				  ". Example: 7 activities with duration 1 in a 5 days week, then transform into 5 activities with durations: 2,2,1,1,1 and add a single container activity with these 5 components"
+				  " (possibly raising the weight of added constraint min days between activities up to 100%)")+
+				  "\n\n"+
+				 tr("2. If you don't add 'force consecutive if same day', then add a larger activity split into a number of"
+				  " activities equal with the number of days per week and the remaining components into other larger split activity."
+				  " For example, suppose you need to add 7 activities with duration 1 in a 5 days week. Add 2 larger container activities,"
+				  " first one split into 5 activities with duration 1 and second one split into 2 activities with duration 1"
+				  " (possibly raising the weight of added constraints min days between activities for each of the 2 containers up to 100%)")+
+			  	 "\n\n"+
+				 tr("Do you want to add current activities as they are now (not recommended) or cancel and edit them as instructed?")
+				  ,
+				 tr("Yes"), tr("No"), QString(), 0, 1);
+
+				if(t==1)
+					return;
+			}
+		}
+		else{
+			if(!halfCheckBox->isChecked() && minDaysDistanceSpinBox->value()>0 && splitSpinBox->value()>gt.rules.nDaysPerWeek/2){
+				int t=LongTextMessageBox::largeConfirmation(this, tr("FET confirmation"),
+				 tr("Possible incorrect setting. Are you sure you want to add current activity? See details below:")+"\n\n"+
+				 tr("You want to add a container activity split into more than the number of real days per week and also add a constraint min days between activities."
+				  " This is a very bad practice from the way the algorithm of generation works (it slows down the generation and makes it harder to find a solution).")+
+				 "\n\n"+
+				 tr("The best way to add the activities would be:")+
+				 "\n\n"+
+				 tr("1. If you add 'force consecutive if same day', then couple extra activities in pairs to obtain a number of activities equal to the number of days per week"
+				  ". Example: 7 activities with duration 1 in a 5 real days week, then transform into 5 activities with durations: 2,2,1,1,1 and add a single container activity with these 5 components"
+				  " (possibly raising the weight of added constraint min days between activities up to 100%)")+
+				  "\n\n"+
+				 tr("2. If you don't add 'force consecutive if same day', then add a larger activity split into a number of"
+				  " activities equal with the number of days per week and the remaining components into other larger split activity."
+				  " For example, suppose you need to add 7 activities with duration 1 in a 5 real days week. Add 2 larger container activities,"
+				  " first one split into 5 activities with duration 1 and second one split into 2 activities with duration 1"
+				  " (possibly raising the weight of added constraints min days between activities for each of the 2 containers up to 100%)")+
+			  	 "\n\n"+
+				 tr("Do you want to add current activities as they are now (not recommended) or cancel and edit them as instructed?")
+				  ,
+				 tr("Yes"), tr("No"), QString(), 0, 1);
+
+				if(t==1)
+					return;
+			}
+			else if(halfCheckBox->isChecked() && minDaysDistanceSpinBox->value()>0 && splitSpinBox->value()>gt.rules.nDaysPerWeek){
+				int t=LongTextMessageBox::largeConfirmation(this, tr("FET confirmation"),
+				 tr("Possible incorrect setting. Are you sure you want to add current activity? See details below:")+"\n\n"+
+				 tr("You want to add a container activity split into more than the number of days per week and also add a constraint min half days between activities."
+				  " This is a very bad practice from the way the algorithm of generation works (it slows down the generation and makes it harder to find a solution).")+
+				 "\n\n"+
+				 tr("The best way to add the activities would be:")+
+				 "\n\n"+
+				 tr("1. If you add 'force consecutive if same day', then couple extra activities in pairs to obtain a number of activities equal to the number of days per week"
+				  ". Example: 12 activities with duration 1 in a 10 days week, then transform into 10 activities with durations: 2,2,1,1,1,1,1,1,1,1 and add a single container"
+				  " activity with these 10 components (possibly raising the weight of added constraint min half days between activities up to 100%)")+
+				  "\n\n"+
+				 tr("2. If you don't add 'force consecutive if same day', then add a larger activity split into a number of"
+				  " activities equal with the number of days per week and the remaining components into other larger split activity."
+				  " For example, suppose you need to add 12 activities with duration 1 in a 10 days week. Add 2 larger container activities,"
+				  " first one split into 10 activities with duration 1 and second one split into 2 activities with duration 1"
+				  " (possibly raising the weight of added constraints min half days between activities for each of the 2 containers up to 100%)")+
+			  	 "\n\n"+
+				 tr("Do you want to add current activities as they are now (not recommended) or cancel and edit them as instructed?")
+				  ,
+				 tr("Yes"), tr("No"), QString(), 0, 1);
+
+				if(t==1)
+					return;
+			}
+		}
+
+		int totalduration;
+		QList<int> durations;
+		QList<bool> active;
+		int nsplit=splitSpinBox->value();
+
+		totalduration=0;
+		for(int i=0; i<nsplit; i++){
+			durations.append(dur(i)->value());
+			active.append(false);
+			if(activ(i)->isChecked())
+				active[i]=true;
+
+			totalduration+=durations[i];
+		}
+
+		//the group id of this split activity and the id of the first partial activity
+		//it is the maximum already existing id + 1
+		int firstactivityid=0;
+		for(int i=0; i<gt.rules.activitiesList.size(); i++){
+			Activity* act=gt.rules.activitiesList[i];
+			if(act->id > firstactivityid)
+				firstactivityid = act->id;
+		}
+		firstactivityid++;
+
+		int cnt_act=0;
+		
+		bool begin=true;
+		bool addSecondConstraint=false;
+		double secondWeight=-1.0;
+		
+		for(int st=0; st<students_names.count(); st++){
+			int n1=nStudentsSpinBox->value();
+			int n2;
+			if(n1==-1)
+				n2=gt.rules.permanentStudentsHash.value(students_names.at(st))->numberOfStudents;
+			else
+				n2=nStudentsSpinBox->value();
+
+			int minD=minDaysDistanceSpinBox->value();
+			bool tmp=gt.rules.addSplitActivityFast(this, firstactivityid, firstactivityid,
+				teachers_names, subject_name, activity_tags_names, QStringList(students_names.at(st)),
+				nsplit, totalduration, durations,
+				active, minD, weight, forceConsecutiveCheckBox->isChecked(),
+				(nStudentsSpinBox->value()==-1), n1, n2, halfCheckBox->isChecked());
+			if(tmp){
+				firstactivityid+=nsplit;
+				cnt_act++;
+			}
+			
+			if(tmp && begin){
+				begin=false;
+				if(minD>1 && weight<100.0){
+					SecondMinDaysDialog second(this, minD, weight);
+					setParentAndOtherThings(&second, this);
+					int code=second.exec();
+	
+					if(code==QDialog::Accepted){
+						addSecondConstraint=true;
+						assert(second.weight>=0 && second.weight<=100.0);
+						secondWeight=second.weight;
+						QList<int> acts;
+						for(int i=0; i<nsplit; i++){
+							acts.append(firstactivityid+i-nsplit);
+						}
+						TimeConstraint* c;
+						if(!halfCheckBox->isChecked())
+							c=new ConstraintMinDaysBetweenActivities(secondWeight, forceConsecutiveCheckBox->isChecked(), nsplit, acts, minD-1);
+						else
+							c=new ConstraintMinHalfDaysBetweenActivities(secondWeight, forceConsecutiveCheckBox->isChecked(), nsplit, acts, minD-1);
+						bool tmp=gt.rules.addTimeConstraint(c);
+						assert(tmp);
+					}
+					else
+						addSecondConstraint=false;
+				}
+			}
+			else if(tmp){
+				if(addSecondConstraint){
+					assert(secondWeight>=0 && secondWeight<=100.0);
+					QList<int> acts;
+					for(int i=0; i<nsplit; i++){
+						acts.append(firstactivityid+i-nsplit);
+					}
+					TimeConstraint* c;
+					if(!halfCheckBox->isChecked())
+						c=new ConstraintMinDaysBetweenActivities(secondWeight, forceConsecutiveCheckBox->isChecked(), nsplit, acts, minD-1);
+					else
+						c=new ConstraintMinHalfDaysBetweenActivities(secondWeight, forceConsecutiveCheckBox->isChecked(), nsplit, acts, minD-1);
+					bool tmp=gt.rules.addTimeConstraint(c);
+					assert(tmp);
+				}
+			}
+		}
+		QMessageBox::information(this, tr("FET information"), tr("%1 split activities added").arg(cnt_act));
+	}
+
+	PlanningChanged::increasePlanningCommunicationSpinBox();
+}
+
 void AddActivityForm::clearTeachers()
 {
 	selectedTeachersListWidget->clear();
@@ -850,6 +1217,9 @@ void AddActivityForm::help()
 	s+="\n";
 	s+=tr("'Split' means 'Split into ... activities per week'");
 	s+="\n";
+	s+=tr("'Half' is only useful in the Mornings-Afternoons mode and it means that, instead of min days between activities, the "
+	 "automatically added constraint(s) will be 'min _half_ days between activities'");
+	s+="\n";
 	s+=tr("'Min days' means 'The minimum required distance in days between each pair of activities'");
 	s+="\n";
 	s+=tr("'Weight %' means 'Percentage of added constraint (min days between activities constraint). Recommended: 95.0%-100.0%'");
@@ -861,13 +1231,8 @@ void AddActivityForm::help()
 	s+="\n";
 	s+=tr("'Qualified' means that only the teachers who are qualified to teach the selected subject will be shown in the 'Teachers' list.",
 	 "Qualified refers to teachers");
-	s+="\n\n";
-	
-	s+=tr("A first notice: "
-	 "If you use a 5 days week: "
-	 "when adding an activity split into only 2 components "
-	 "per week, the best practice is to add min days between activities to be 2. "
-	 "If you split an activity into 3 components per week - please read FAQ question Q1-5-September-2008");
+	s+="\n";
+	s+=tr("'Separately' means that multiple activities will be added, one for each selected students set, separately.");
 	s+="\n\n";
 	
 	s+=tr("You can select a teacher from all the teachers with the mouse or with the keyboard tab/up/down, then "
@@ -934,9 +1299,7 @@ void AddActivityForm::help()
 
 	s+="\n\n";
 
-	s+=tr("Current algorithm cannot schedule 3 activities in the same day if consecutive is checked, so "
-	 "you will get no solution in such extreme cases (for instance, if you have 3 lessons and a teacher which works only 1 day per week, "
-	 "and select 'force consecutive if same day', you will get an imposssible timetable. But these are extremely unlikely cases).");
+	s+=tr("The current algorithm will not schedule 3 or more activities on the same day if you add a min days between activities constraint.");
 
 	s+="\n\n";
 	
@@ -981,7 +1344,18 @@ void AddActivityForm::help()
 
 void AddActivityForm::minDaysChanged()
 {
-	percentageTextLabel->setEnabled(splitSpinBox->value()>=2 && minDayDistanceSpinBox->value()>0);
-	percentageLineEdit->setEnabled(splitSpinBox->value()>=2 && minDayDistanceSpinBox->value()>0);
-	forceConsecutiveCheckBox->setEnabled(splitSpinBox->value()>=2 && minDayDistanceSpinBox->value()>0);
+	percentageTextLabel->setEnabled(splitSpinBox->value()>=2 && minDaysDistanceSpinBox->value()>0);
+	percentageLineEdit->setEnabled(splitSpinBox->value()>=2 && minDaysDistanceSpinBox->value()>0);
+	forceConsecutiveCheckBox->setEnabled(splitSpinBox->value()>=2 && minDaysDistanceSpinBox->value()>0);
+}
+
+void AddActivityForm::halfCheckBoxToggled()
+{
+	//The assert below should be OK, because if the mode is not Mornings-Afternoons the check box should be disabled,
+	//and the connection is done in the constructor after unchecking it and disabling it. But I consider that it is better to disable the assert.
+	//assert(gt.rules.mode==MORNINGS_AFTERNOONS);
+	if(halfCheckBox->isChecked())
+		minDaysDistanceSpinBox->setMaximum(gt.rules.nDaysPerWeek-1);
+	else
+		minDaysDistanceSpinBox->setMaximum(gt.rules.nDaysPerWeek/2-1);
 }
