@@ -101,7 +101,7 @@ AddConstraintActivitiesOccupyMaxDifferentRoomsForm::~AddConstraintActivitiesOccu
 
 void AddConstraintActivitiesOccupyMaxDifferentRoomsForm::addCurrentConstraint()
 {
-	SpaceConstraint *ctr=NULL;
+	SpaceConstraint *ctr=nullptr;
 
 	double weight;
 	QString tmp=weightLineEdit->text();
