@@ -97,7 +97,7 @@ AddConstraintActivitiesSameRoomIfConsecutiveForm::~AddConstraintActivitiesSameRo
 
 void AddConstraintActivitiesSameRoomIfConsecutiveForm::addCurrentConstraint()
 {
-	SpaceConstraint *ctr=NULL;
+	SpaceConstraint *ctr=nullptr;
 
 	double weight;
 	QString tmp=weightLineEdit->text();
