@@ -157,7 +157,7 @@ void AddConstraintActivitiesSameStartingHourForm::filterChanged()
 
 void AddConstraintActivitiesSameStartingHourForm::addConstraint()
 {
-	TimeConstraint *ctr=NULL;
+	TimeConstraint *ctr=nullptr;
 
 	double weight;
 	QString tmp=weightLineEdit->text();
