@@ -35,6 +35,8 @@ AddConstraintActivitiesSameStartingTimeForm::AddConstraintActivitiesSameStarting
 	
 	allActivitiesListWidget->setSelectionMode(QAbstractItemView::SingleSelection);
 	selectedActivitiesListWidget->setSelectionMode(QAbstractItemView::SingleSelection);
+	
+	blockCheckBox->setChecked(false);
 
 	connect(closePushButton, SIGNAL(clicked()), this, SLOT(close()));
 	connect(addConstraintPushButton, SIGNAL(clicked()), this, SLOT(addConstraint()));
@@ -183,7 +185,7 @@ void AddConstraintActivitiesSameStartingTimeForm::blockChanged()
 
 void AddConstraintActivitiesSameStartingTimeForm::addConstraint()
 {
-	TimeConstraint *ctr=NULL;
+	TimeConstraint *ctr=nullptr;
 
 	double weight;
 	QString tmp=weightLineEdit->text();
@@ -196,7 +198,7 @@ void AddConstraintActivitiesSameStartingTimeForm::addConstraint()
 
 	if(this->selectedActivitiesList.count()==0){
 		QMessageBox::warning(this, tr("FET information"),
-			tr("Empty list of simultaneous activities"));
+			tr("Empty list of selected activities"));
 		return;
 	}
 	if(this->selectedActivitiesList.count()==1){
@@ -253,7 +255,7 @@ void AddConstraintActivitiesSameStartingTimeForm::addConstraint()
 		}
 	
 		/////////////phase 2 - compute the indices of all the (sub)activities
-		Matrix1D<QList<int> > ids;
+		Matrix1D<QList<int>> ids;
 		ids.resize(nConstraints);
 
 		for(int i=0; i<nConstraints; i++)
@@ -405,7 +407,7 @@ void AddConstraintActivitiesSameStartingTimeForm::help()
 	s=tr("Add multiple constraints: this is a check box. Select this if you want to input only the representatives of sub-activities and FET to add multiple constraints,"
 	" for all sub-activities from the same components, in turn, respectively."
 	" There will be added more constraints activities same starting time, one for each corresponding tuple. The number of"
-	" sub-activities must match for the representants and be careful to the order, to be what you need");
+	" sub-activities must match for the representatives and be careful to the order, to be what you need");
 
 	LongTextMessageBox::largeInformation(this, tr("FET help"), s);
 }
