@@ -212,7 +212,7 @@ void AddConstraintActivityPreferredRoomForm::addRealRoom()
 
 void AddConstraintActivityPreferredRoomForm::addConstraint()
 {
-	SpaceConstraint *ctr=NULL;
+	SpaceConstraint *ctr=nullptr;
 
 	double weight;
 	QString tmp=weightLineEdit->text();
@@ -295,7 +295,7 @@ void AddConstraintActivityPreferredRoomForm::addConstraint()
 		if(!incorrectList.isEmpty()){
 			switch(LongTextMessageBox::confirmation(this, tr("FET information"), tr("The selected real rooms: %1 are not found in the sets of sets of real rooms of the"
 			 " selected preferred virtual room. This is probably wrong. Are you sure you want to add this constraint?").arg(incorrectList.join(", ")),
-			 tr("Yes"), tr("No"), 0, 0, 1)){
+			 tr("Yes"), tr("No"), QString(), 0, 1)){
 			case 0:
 				break;
 			case 1:
