@@ -162,7 +162,7 @@ void AddConstraintActivityPreferredStartingTimeForm::updatePeriodGroupBox(){
 
 void AddConstraintActivityPreferredStartingTimeForm::addCurrentConstraint()
 {
-	TimeConstraint *ctr=NULL;
+	TimeConstraint *ctr=nullptr;
 
 	double weight;
 	QString tmp=weightLineEdit->text();
