@@ -160,7 +160,7 @@ void AddConstraintMinGapsBetweenActivitiesForm::filterChanged()
 
 void AddConstraintMinGapsBetweenActivitiesForm::addConstraint()
 {
-	TimeConstraint *ctr=NULL;
+	TimeConstraint *ctr=nullptr;
 
 	double weight;
 	QString tmp=weightLineEdit->text();
