@@ -57,7 +57,7 @@ void AddConstraintStudentsActivityTagMaxHoursDailyForm::updateActivityTagsComboB
 
 void AddConstraintStudentsActivityTagMaxHoursDailyForm::addCurrentConstraint()
 {
-	TimeConstraint *ctr=NULL;
+	TimeConstraint *ctr=nullptr;
 
 	double weight;
 	QString tmp=weightLineEdit->text();
