@@ -74,7 +74,7 @@ void AddConstraintStudentsIntervalMaxDaysPerWeekForm::updateEndHoursComboBox()
 
 void AddConstraintStudentsIntervalMaxDaysPerWeekForm::addCurrentConstraint()
 {
-	TimeConstraint *ctr=NULL;
+	TimeConstraint *ctr=nullptr;
 
 	double weight;
 	QString tmp=weightLineEdit->text();
