@@ -46,7 +46,7 @@ AddConstraintStudentsMaxRoomChangesPerDayForm::~AddConstraintStudentsMaxRoomChan
 
 void AddConstraintStudentsMaxRoomChangesPerDayForm::addCurrentConstraint()
 {
-	SpaceConstraint *ctr=NULL;
+	SpaceConstraint *ctr=nullptr;
 
 	double weight;
 	QString tmp=weightLineEdit->text();
