@@ -46,7 +46,7 @@ AddConstraintStudentsMaxRoomChangesPerWeekForm::~AddConstraintStudentsMaxRoomCha
 
 void AddConstraintStudentsMaxRoomChangesPerWeekForm::addCurrentConstraint()
 {
-	SpaceConstraint *ctr=NULL;
+	SpaceConstraint *ctr=nullptr;
 
 	double weight;
 	QString tmp=weightLineEdit->text();
