@@ -31,6 +31,8 @@ AddConstraintStudentsMinGapsBetweenOrderedPairOfActivityTagsForm::AddConstraintS
 	connect(addConstraintPushButton, SIGNAL(clicked()), this, SLOT(addCurrentConstraint()));
 	connect(closePushButton, SIGNAL(clicked()), this, SLOT(close()));
 
+	connect(swapPushButton, SIGNAL(clicked()), this, SLOT(swap()));
+
 	centerWidgetOnScreen(this);
 	restoreFETDialogGeometry(this);
 	
@@ -45,6 +47,14 @@ AddConstraintStudentsMinGapsBetweenOrderedPairOfActivityTagsForm::AddConstraintS
 
 	updateFirstActivityTagComboBox();
 	updateSecondActivityTagComboBox();
+	
+	if(firstActivityTagComboBox->count()>=1)
+		firstActivityTagComboBox->setCurrentIndex(0);
+
+	if(secondActivityTagComboBox->count()>=2)
+		secondActivityTagComboBox->setCurrentIndex(1);
+	else if(secondActivityTagComboBox->count()>=1)
+		secondActivityTagComboBox->setCurrentIndex(0);
 }
 
 AddConstraintStudentsMinGapsBetweenOrderedPairOfActivityTagsForm::~AddConstraintStudentsMinGapsBetweenOrderedPairOfActivityTagsForm()
@@ -66,7 +76,7 @@ void AddConstraintStudentsMinGapsBetweenOrderedPairOfActivityTagsForm::updateSec
 
 void AddConstraintStudentsMinGapsBetweenOrderedPairOfActivityTagsForm::addCurrentConstraint()
 {
-	TimeConstraint *ctr=NULL;
+	TimeConstraint *ctr=nullptr;
 
 	double weight;
 	QString tmp=weightLineEdit->text();
@@ -115,3 +125,11 @@ void AddConstraintStudentsMinGapsBetweenOrderedPairOfActivityTagsForm::addCurren
 		delete ctr;
 	}
 }
+
+void AddConstraintStudentsMinGapsBetweenOrderedPairOfActivityTagsForm::swap()
+{
+	int t1=firstActivityTagComboBox->currentIndex();
+	int t2=secondActivityTagComboBox->currentIndex();
+	firstActivityTagComboBox->setCurrentIndex(t2);
+	secondActivityTagComboBox->setCurrentIndex(t1);
+}
