@@ -46,7 +46,7 @@ AddConstraintStudentsMinGapsBetweenRoomChangesForm::~AddConstraintStudentsMinGap
 
 void AddConstraintStudentsMinGapsBetweenRoomChangesForm::addCurrentConstraint()
 {
-	SpaceConstraint *ctr=NULL;
+	SpaceConstraint *ctr=nullptr;
 
 	double weight;
 	QString tmp=weightLineEdit->text();
