@@ -68,7 +68,7 @@ void AddConstraintStudentsSetActivityTagMinHoursDailyForm::updateActivityTagsCom
 
 void AddConstraintStudentsSetActivityTagMinHoursDailyForm::addCurrentConstraint()
 {
-	TimeConstraint *ctr=NULL;
+	TimeConstraint *ctr=nullptr;
 
 	double weight;
 	QString tmp=weightLineEdit->text();
@@ -83,7 +83,7 @@ void AddConstraintStudentsSetActivityTagMinHoursDailyForm::addCurrentConstraint(
 
 	QString students_name=studentsComboBox->currentText();
 	StudentsSet* s=gt.rules.searchStudentsSet(students_name);
-	if(s==NULL){
+	if(s==nullptr){
 		QMessageBox::warning(this, tr("FET warning"),
 			tr("Invalid students set"));
 		return;
