@@ -56,7 +56,7 @@ void AddConstraintStudentsSetMaxBuildingChangesPerDayForm::updateStudentsSetComb
 
 void AddConstraintStudentsSetMaxBuildingChangesPerDayForm::addCurrentConstraint()
 {
-	SpaceConstraint *ctr=NULL;
+	SpaceConstraint *ctr=nullptr;
 
 	double weight;
 	QString tmp=weightLineEdit->text();
@@ -69,7 +69,7 @@ void AddConstraintStudentsSetMaxBuildingChangesPerDayForm::addCurrentConstraint(
 
 	QString students_name=studentsComboBox->currentText();
 	StudentsSet* s=gt.rules.searchStudentsSet(students_name);
-	if(s==NULL){
+	if(s==nullptr){
 		QMessageBox::warning(this, tr("FET information"),
 			tr("Invalid students set"));
 		return;
