@@ -59,7 +59,7 @@ void AddConstraintStudentsSetMaxDaysPerWeekForm::updateMaxDaysSpinBox(){
 
 void AddConstraintStudentsSetMaxDaysPerWeekForm::addCurrentConstraint()
 {
-	TimeConstraint *ctr=NULL;
+	TimeConstraint *ctr=nullptr;
 
 	double weight;
 	QString tmp=weightLineEdit->text();
@@ -79,7 +79,7 @@ void AddConstraintStudentsSetMaxDaysPerWeekForm::addCurrentConstraint()
 
 	QString students_name=studentsComboBox->currentText();
 	StudentsSet* s=gt.rules.searchStudentsSet(students_name);
-	if(s==NULL){
+	if(s==nullptr){
 		QMessageBox::warning(this, tr("FET information"),
 			tr("Invalid students set"));
 		return;
