@@ -56,7 +56,7 @@ void AddConstraintStudentsSetMaxHoursDailyForm::updateStudentsSetComboBox()
 
 void AddConstraintStudentsSetMaxHoursDailyForm::addCurrentConstraint()
 {
-	TimeConstraint *ctr=NULL;
+	TimeConstraint *ctr=nullptr;
 
 	double weight;
 	QString tmp=weightLineEdit->text();
@@ -80,7 +80,7 @@ void AddConstraintStudentsSetMaxHoursDailyForm::addCurrentConstraint()
 
 	QString students_name=studentsComboBox->currentText();
 	StudentsSet* s=gt.rules.searchStudentsSet(students_name);
-	if(s==NULL){
+	if(s==nullptr){
 		QMessageBox::warning(this, tr("FET information"),
 			tr("Invalid students set"));
 		return;
