@@ -31,6 +31,8 @@ AddConstraintStudentsSetMinGapsBetweenOrderedPairOfActivityTagsForm::AddConstrai
 	connect(addConstraintPushButton, SIGNAL(clicked()), this, SLOT(addCurrentConstraint()));
 	connect(closePushButton, SIGNAL(clicked()), this, SLOT(close()));
 
+	connect(swapPushButton, SIGNAL(clicked()), this, SLOT(swap()));
+
 	centerWidgetOnScreen(this);
 	restoreFETDialogGeometry(this);
 	
@@ -49,6 +51,14 @@ AddConstraintStudentsSetMinGapsBetweenOrderedPairOfActivityTagsForm::AddConstrai
 	
 	updateFirstActivityTagComboBox();
 	updateSecondActivityTagComboBox();
+
+	if(firstActivityTagComboBox->count()>=1)
+		firstActivityTagComboBox->setCurrentIndex(0);
+
+	if(secondActivityTagComboBox->count()>=2)
+		secondActivityTagComboBox->setCurrentIndex(1);
+	else if(secondActivityTagComboBox->count()>=1)
+		secondActivityTagComboBox->setCurrentIndex(0);
 }
 
 AddConstraintStudentsSetMinGapsBetweenOrderedPairOfActivityTagsForm::~AddConstraintStudentsSetMinGapsBetweenOrderedPairOfActivityTagsForm()
@@ -75,7 +85,7 @@ void AddConstraintStudentsSetMinGapsBetweenOrderedPairOfActivityTagsForm::update
 
 void AddConstraintStudentsSetMinGapsBetweenOrderedPairOfActivityTagsForm::addCurrentConstraint()
 {
-	TimeConstraint *ctr=NULL;
+	TimeConstraint *ctr=nullptr;
 
 	double weight;
 	QString tmp=weightLineEdit->text();
@@ -95,7 +105,7 @@ void AddConstraintStudentsSetMinGapsBetweenOrderedPairOfActivityTagsForm::addCur
 
 	QString students_name=studentsComboBox->currentText();
 	StudentsSet* s=gt.rules.searchStudentsSet(students_name);
-	if(s==NULL){
+	if(s==nullptr){
 		QMessageBox::warning(this, tr("FET warning"),
 			tr("Invalid students set"));
 		return;
@@ -132,3 +142,11 @@ void AddConstraintStudentsSetMinGapsBetweenOrderedPairOfActivityTagsForm::addCur
 		delete ctr;
 	}
 }
+
+void AddConstraintStudentsSetMinGapsBetweenOrderedPairOfActivityTagsForm::swap()
+{
+	int t1=firstActivityTagComboBox->currentIndex();
+	int t2=secondActivityTagComboBox->currentIndex();
+	firstActivityTagComboBox->setCurrentIndex(t2);
+	secondActivityTagComboBox->setCurrentIndex(t1);
+}
