@@ -36,7 +36,7 @@ AddConstraintStudentsSetMinGapsBetweenRoomChangesForm::AddConstraintStudentsSetM
 
 	QSize tmp2=studentsComboBox->minimumSizeHint();
 	Q_UNUSED(tmp2);
-		
+	
 	minGapsSpinBox->setMinimum(1);
 	minGapsSpinBox->setMaximum(gt.rules.nHoursPerDay);
 	minGapsSpinBox->setValue(1);
@@ -56,7 +56,7 @@ void AddConstraintStudentsSetMinGapsBetweenRoomChangesForm::updateStudentsSetCom
 
 void AddConstraintStudentsSetMinGapsBetweenRoomChangesForm::addCurrentConstraint()
 {
-	SpaceConstraint *ctr=NULL;
+	SpaceConstraint *ctr=nullptr;
 
 	double weight;
 	QString tmp=weightLineEdit->text();
@@ -69,7 +69,7 @@ void AddConstraintStudentsSetMinGapsBetweenRoomChangesForm::addCurrentConstraint
 
 	QString students_name=studentsComboBox->currentText();
 	StudentsSet* s=gt.rules.searchStudentsSet(students_name);
-	if(s==NULL){
+	if(s==nullptr){
 		QMessageBox::warning(this, tr("FET information"),
 			tr("Invalid students set"));
 		return;
