@@ -34,7 +34,7 @@ AddConstraintStudentsSetMinHoursDailyForm::AddConstraintStudentsSetMinHoursDaily
 	centerWidgetOnScreen(this);
 	restoreFETDialogGeometry(this);
 	
-	if(ENABLE_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS)
+	if(gt.rules.mode==MORNINGS_AFTERNOONS || ENABLE_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS)
 		allowLabel->setText(tr("Advanced usage: enabled"));
 	else
 		allowLabel->setText(tr("Advanced usage: not enabled"));
@@ -44,9 +44,17 @@ AddConstraintStudentsSetMinHoursDailyForm::AddConstraintStudentsSetMinHoursDaily
 
 	minHoursSpinBox->setMinimum(1);
 	minHoursSpinBox->setMaximum(gt.rules.nHoursPerDay);
-	minHoursSpinBox->setValue(1);
 
 	updateStudentsSetComboBox();
+	
+	if(gt.rules.mode==MORNINGS_AFTERNOONS){
+		minHoursSpinBox->setValue(2);
+		allowEmptyDaysCheckBox->setChecked(true);
+	}
+	else{
+		minHoursSpinBox->setValue(1);
+		allowEmptyDaysCheckBox->setChecked(false);
+	}
 }
 
 AddConstraintStudentsSetMinHoursDailyForm::~AddConstraintStudentsSetMinHoursDailyForm()
@@ -61,7 +69,7 @@ void AddConstraintStudentsSetMinHoursDailyForm::updateStudentsSetComboBox()
 
 void AddConstraintStudentsSetMinHoursDailyForm::addCurrentConstraint()
 {
-	TimeConstraint *ctr=NULL;
+	TimeConstraint *ctr=nullptr;
 
 	double weight;
 	QString tmp=weightLineEdit->text();
@@ -77,21 +85,23 @@ void AddConstraintStudentsSetMinHoursDailyForm::addCurrentConstraint()
 		return;
 	}
 
-	if(!ENABLE_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS && allowEmptyDaysCheckBox->isChecked()){
-		QMessageBox::warning(this, tr("FET warning"), tr("Empty days for students min hours daily constraints are not enabled. You must enable them from the Settings->Advanced menu."));
-		return;
-	}
-
-	if(allowEmptyDaysCheckBox->isChecked() && minHoursSpinBox->value()<2){
-		QMessageBox::warning(this, tr("FET warning"), tr("If you allow empty days, the min hours must be at least 2 (to make it a non-trivial constraint)"));
-		return;
+	if(gt.rules.mode!=MORNINGS_AFTERNOONS){
+		if(!ENABLE_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS && allowEmptyDaysCheckBox->isChecked()){
+			QMessageBox::warning(this, tr("FET warning"), tr("Empty days for students min hours daily constraints are not enabled. You must enable them from the Settings->Advanced menu."));
+			return;
+		}
+	
+		if(allowEmptyDaysCheckBox->isChecked() && minHoursSpinBox->value()<2){
+			QMessageBox::warning(this, tr("FET warning"), tr("If you allow empty days, the min hours must be at least 2 (to make it a non-trivial constraint)"));
+			return;
+		}
 	}
 
 	int minHours=minHoursSpinBox->value();
 
 	QString students_name=studentsComboBox->currentText();
 	StudentsSet* s=gt.rules.searchStudentsSet(students_name);
-	if(s==NULL){
+	if(s==nullptr){
 		QMessageBox::warning(this, tr("FET information"),
 			tr("Invalid students set"));
 		return;
@@ -112,17 +122,19 @@ void AddConstraintStudentsSetMinHoursDailyForm::addCurrentConstraint()
 
 void AddConstraintStudentsSetMinHoursDailyForm::on_allowEmptyDaysCheckBox_toggled()
 {
-	bool k=allowEmptyDaysCheckBox->isChecked();
+	if(gt.rules.mode!=MORNINGS_AFTERNOONS){
+		bool k=allowEmptyDaysCheckBox->isChecked();
 		
-	if(k && !ENABLE_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS){
-		allowEmptyDaysCheckBox->setChecked(false);
-		QString s=tr("Advanced usage is not enabled. To be able to select 'Allow empty days' for the constraints of type min hours daily for students, you must enable the option from the Settings->Advanced menu.",
-			"'Allow empty days' is an option which the user can enable and then he can select it.");
-		s+="\n\n";
-		s+=tr("Explanation: only select this option if your institution allows empty days for students and a timetable is possible with empty days for students."
-			" Otherwise, it is IMPERATIVE (for performance reasons) to not select this option (or FET may not be able to find a timetable).");
-		s+="\n\n";
-		s+=tr("Use with caution.");
-		QMessageBox::information(this, tr("FET information"), s);
+		if(k && !ENABLE_STUDENTS_MIN_HOURS_DAILY_WITH_ALLOW_EMPTY_DAYS){
+			allowEmptyDaysCheckBox->setChecked(false);
+			QString s=tr("Advanced usage is not enabled. To be able to select 'Allow empty days' for the constraints of type min hours daily for students, you must enable the option from the Settings->Advanced menu.",
+				"'Allow empty days' is an option which the user can enable and then he can select it.");
+			s+="\n\n";
+			s+=tr("Explanation: only select this option if your institution allows empty days for students and a timetable is possible with empty days for students."
+				" Otherwise, it is IMPERATIVE (for performance reasons) to not select this option (or FET may not be able to find a timetable).");
+			s+="\n\n";
+			s+=tr("Use with caution.");
+			QMessageBox::information(this, tr("FET information"), s);
+		}
 	}
 }
