@@ -65,7 +65,7 @@ void AddConstraintTeacherActivityTagMaxHoursDailyForm::updateMaxHoursSpinBox(){
 
 void AddConstraintTeacherActivityTagMaxHoursDailyForm::addCurrentConstraint()
 {
-	TimeConstraint *ctr=NULL;
+	TimeConstraint *ctr=nullptr;
 
 	double weight;
 	QString tmp=weightLineEdit->text();
