@@ -57,7 +57,7 @@ void AddConstraintTeachersActivityTagMaxHoursContinuouslyForm::updateMaxHoursSpi
 
 void AddConstraintTeachersActivityTagMaxHoursContinuouslyForm::addCurrentConstraint()
 {
-	TimeConstraint *ctr=NULL;
+	TimeConstraint *ctr=nullptr;
 
 	double weight;
 	QString tmp=weightLineEdit->text();
