@@ -46,7 +46,7 @@ AddConstraintTeachersMaxRoomChangesPerDayForm::~AddConstraintTeachersMaxRoomChan
 
 void AddConstraintTeachersMaxRoomChangesPerDayForm::addCurrentConstraint()
 {
-	SpaceConstraint *ctr=NULL;
+	SpaceConstraint *ctr=nullptr;
 
 	double weight;
 	QString tmp=weightLineEdit->text();
