@@ -46,7 +46,7 @@ AddConstraintTeachersMaxRoomChangesPerWeekForm::~AddConstraintTeachersMaxRoomCha
 
 void AddConstraintTeachersMaxRoomChangesPerWeekForm::addCurrentConstraint()
 {
-	SpaceConstraint *ctr=NULL;
+	SpaceConstraint *ctr=nullptr;
 
 	double weight;
 	QString tmp=weightLineEdit->text();
