@@ -48,7 +48,7 @@ AddConstraintTeachersMaxSpanPerDayForm::~AddConstraintTeachersMaxSpanPerDayForm(
 
 void AddConstraintTeachersMaxSpanPerDayForm::addCurrentConstraint()
 {
-	TimeConstraint *ctr=NULL;
+	TimeConstraint *ctr=nullptr;
 
 	double weight;
 	QString tmp=weightLineEdit->text();
