@@ -46,7 +46,7 @@ AddConstraintTeachersMinGapsBetweenRoomChangesForm::~AddConstraintTeachersMinGap
 
 void AddConstraintTeachersMinGapsBetweenRoomChangesForm::addCurrentConstraint()
 {
-	SpaceConstraint *ctr=NULL;
+	SpaceConstraint *ctr=nullptr;
 
 	double weight;
 	QString tmp=weightLineEdit->text();
