@@ -151,11 +151,19 @@ void AddConstraintTwoActivitiesOrderedIfSameDayForm::filterChanged(){
 			this->secondActivitiesList.append(act->id);
 		}
 	}
+
+	if(firstActivitiesComboBox->count()>=1)
+		firstActivitiesComboBox->setCurrentIndex(0);
+
+	if(secondActivitiesComboBox->count()>=2)
+		secondActivitiesComboBox->setCurrentIndex(1);
+	else if(secondActivitiesComboBox->count()>=1)
+		secondActivitiesComboBox->setCurrentIndex(0);
 }
 
 void AddConstraintTwoActivitiesOrderedIfSameDayForm::addCurrentConstraint()
 {
-	TimeConstraint *ctr=NULL;
+	TimeConstraint *ctr=nullptr;
 
 	double weight;
 	QString tmp=weightLineEdit->text();
