@@ -23,6 +23,7 @@
 
 #include "modifyconstraintbasiccompulsoryspaceform.h"
 #include "modifyconstraintroomnotavailabletimesform.h"
+#include "modifyconstraintteacherroomnotavailabletimesform.h"
 #include "modifyconstraintactivitypreferredroomform.h"
 #include "modifyconstraintactivitypreferredroomsform.h"
 
@@ -46,6 +47,12 @@
 #include "modifyconstraintteachermingapsbetweenbuildingchangesform.h"
 #include "modifyconstraintteachersmingapsbetweenbuildingchangesform.h"
 
+#include "modifyconstraintstudentssetmaxroomchangesperrealdayform.h"
+#include "modifyconstraintstudentsmaxroomchangesperrealdayform.h"
+
+#include "modifyconstraintstudentssetmaxbuildingchangesperrealdayform.h"
+#include "modifyconstraintstudentsmaxbuildingchangesperrealdayform.h"
+
 #include "modifyconstraintstudentssetmaxroomchangesperdayform.h"
 #include "modifyconstraintstudentsmaxroomchangesperdayform.h"
 #include "modifyconstraintstudentssetmaxroomchangesperweekform.h"
@@ -53,6 +60,12 @@
 #include "modifyconstraintstudentssetmingapsbetweenroomchangesform.h"
 #include "modifyconstraintstudentsmingapsbetweenroomchangesform.h"
 
+#include "modifyconstraintteachermaxroomchangesperrealdayform.h"
+#include "modifyconstraintteachersmaxroomchangesperrealdayform.h"
+
+#include "modifyconstraintteachermaxbuildingchangesperrealdayform.h"
+#include "modifyconstraintteachersmaxbuildingchangesperrealdayform.h"
+
 #include "modifyconstraintteachermaxroomchangesperdayform.h"
 #include "modifyconstraintteachersmaxroomchangesperdayform.h"
 #include "modifyconstraintteachermaxroomchangesperweekform.h"
@@ -404,7 +417,7 @@ void AllSpaceConstraintsForm::sortedChanged(bool checked)
 static int spaceConstraintsAscendingByDescription(SpaceConstraint* s1, SpaceConstraint* s2)
 {
 	//return s1->getDescription(gt.rules) < s2->getDescription(gt.rules);
-	//by rodolforg
+	//by Rodolfo Ribeiro Gomes
 	return s1->getDescription(gt.rules).localeAwareCompare(s2->getDescription(gt.rules))<0;
 }
 
@@ -449,7 +462,7 @@ void AllSpaceConstraintsForm::constraintChanged()
 
 	assert(index<visibleSpaceConstraintsList.count());
 	SpaceConstraint* ctr=visibleSpaceConstraintsList.at(index);
-	assert(ctr!=NULL);
+	assert(ctr!=nullptr);
 	QString s=ctr->getDetailedDescription(gt.rules);
 	currentConstraintTextEdit->setPlainText(s);
 }
@@ -714,6 +727,61 @@ void AllSpaceConstraintsForm::modifyConstraint()
 		setParentAndOtherThings(&form, this);
 		form.exec();
 	}
+	//41
+	else if(ctr->type==CONSTRAINT_TEACHER_ROOM_NOT_AVAILABLE_TIMES){
+		ModifyConstraintTeacherRoomNotAvailableTimesForm form(this, (ConstraintTeacherRoomNotAvailableTimes*)ctr);
+		setParentAndOtherThings(&form, this);
+		form.exec();
+	}
+	//for mornings-afternoons
+	//42
+	else if(ctr->type==CONSTRAINT_STUDENTS_SET_MAX_ROOM_CHANGES_PER_REAL_DAY){
+		ModifyConstraintStudentsSetMaxRoomChangesPerRealDayForm form(this, (ConstraintStudentsSetMaxRoomChangesPerRealDay*)ctr);
+		setParentAndOtherThings(&form, this);
+		form.exec();
+	}
+	//43
+	else if(ctr->type==CONSTRAINT_STUDENTS_MAX_ROOM_CHANGES_PER_REAL_DAY){
+		ModifyConstraintStudentsMaxRoomChangesPerRealDayForm form(this, (ConstraintStudentsMaxRoomChangesPerRealDay*)ctr);
+		setParentAndOtherThings(&form, this);
+		form.exec();
+	}
+	//44
+	else if(ctr->type==CONSTRAINT_TEACHER_MAX_ROOM_CHANGES_PER_REAL_DAY){
+		ModifyConstraintTeacherMaxRoomChangesPerRealDayForm form(this, (ConstraintTeacherMaxRoomChangesPerRealDay*)ctr);
+		setParentAndOtherThings(&form, this);
+		form.exec();
+	}
+	//45
+	else if(ctr->type==CONSTRAINT_TEACHERS_MAX_ROOM_CHANGES_PER_REAL_DAY){
+		ModifyConstraintTeachersMaxRoomChangesPerRealDayForm form(this, (ConstraintTeachersMaxRoomChangesPerRealDay*)ctr);
+		setParentAndOtherThings(&form, this);
+		form.exec();
+	}
+	//46
+	else if(ctr->type==CONSTRAINT_STUDENTS_SET_MAX_BUILDING_CHANGES_PER_REAL_DAY){
+		ModifyConstraintStudentsSetMaxBuildingChangesPerRealDayForm form(this, (ConstraintStudentsSetMaxBuildingChangesPerRealDay*)ctr);
+		setParentAndOtherThings(&form, this);
+		form.exec();
+	}
+	//47
+	else if(ctr->type==CONSTRAINT_STUDENTS_MAX_BUILDING_CHANGES_PER_REAL_DAY){
+		ModifyConstraintStudentsMaxBuildingChangesPerRealDayForm form(this, (ConstraintStudentsMaxBuildingChangesPerRealDay*)ctr);
+		setParentAndOtherThings(&form, this);
+		form.exec();
+	}
+	//48
+	else if(ctr->type==CONSTRAINT_TEACHER_MAX_BUILDING_CHANGES_PER_REAL_DAY){
+		ModifyConstraintTeacherMaxBuildingChangesPerRealDayForm form(this, (ConstraintTeacherMaxBuildingChangesPerRealDay*)ctr);
+		setParentAndOtherThings(&form, this);
+		form.exec();
+	}
+	//49
+	else if(ctr->type==CONSTRAINT_TEACHERS_MAX_BUILDING_CHANGES_PER_REAL_DAY){
+		ModifyConstraintTeachersMaxBuildingChangesPerRealDayForm form(this, (ConstraintTeachersMaxBuildingChangesPerRealDay*)ctr);
+		setParentAndOtherThings(&form, this);
+		form.exec();
+	}
 	else{
 		QMessageBox::critical(this, tr("FET critical"), tr("You have found a bug in FET. Please report it. This kind of constraint"
 		 " is not correctly recognized in all space constraints dialog. FET will skip this error, so that you can continue work."
@@ -756,8 +824,8 @@ void AllSpaceConstraintsForm::removeConstraint()
 	QListWidgetItem* item;
 	
 	int lres=LongTextMessageBox::confirmation( this, tr("FET confirmation"),
-		s, tr("Yes"), tr("No"), 0, 0, 1 );
-		
+		s, tr("Yes"), tr("No"), QString(), 0, 1 );
+	
 	if(lres==0){ //The user clicked the OK button or pressed Enter
 		QMessageBox::StandardButton wr=QMessageBox::Yes;
 		
