@@ -116,13 +116,13 @@ bool ConstraintActivitiesOccupyMaxTimeSlotsFromSelectionForm::filterOk(TimeConst
 		
 	for(int i=0; i<c->activitiesIds.count(); i++){
 		int id=c->activitiesIds.at(i);
-		/*Activity* act=NULL;
+		/*Activity* act=nullptr;
 		for(Activity* a : qAsConst(gt.rules.activitiesList))
 			if(a->id==id)
 				act=a;*/
-		Activity* act=gt.rules.activitiesPointerHash.value(id, NULL);
+		Activity* act=gt.rules.activitiesPointerHash.value(id, nullptr);
 		
-		if(act!=NULL){
+		if(act!=nullptr){
 			//teacher
 			if(tn!=""){
 				bool ok2=false;
@@ -197,7 +197,7 @@ void ConstraintActivitiesOccupyMaxTimeSlotsFromSelectionForm::constraintChanged(
 	}
 	assert(index<this->visibleConstraintsList.size());
 	TimeConstraint* ctr=this->visibleConstraintsList.at(index);
-	assert(ctr!=NULL);
+	assert(ctr!=nullptr);
 	currentConstraintTextEdit->setPlainText(ctr->getDetailedDescription(gt.rules));
 }
 
@@ -258,7 +258,7 @@ void ConstraintActivitiesOccupyMaxTimeSlotsFromSelectionForm::removeConstraint()
 	QListWidgetItem* item;
 
 	switch( LongTextMessageBox::confirmation( this, tr("FET confirmation"),
-		s, tr("Yes"), tr("No"), 0, 0, 1 ) ){
+		s, tr("Yes"), tr("No"), QString(), 0, 1 ) ){
 	case 0: // The user clicked the OK button or pressed Enter
 		gt.rules.removeTimeConstraint(ctr);
 		
