@@ -122,15 +122,15 @@ bool ConstraintActivityPreferredRoomForm::filterOk(SpaceConstraint* ctr)
 	bool found=true;
 	
 	int id=c->activityId;
-	/*Activity* act=NULL;
+	/*Activity* act=nullptr;
 	for(Activity* a : qAsConst(gt.rules.activitiesList))
 		if(a->id==id)
 			act=a;*/
-	Activity* act=gt.rules.activitiesPointerHash.value(id, NULL);
+	Activity* act=gt.rules.activitiesPointerHash.value(id, nullptr);
 	
 	found=true;
 		
-	if(act!=NULL){
+	if(act!=nullptr){
 		//teacher
 		if(tn!=""){
 			bool ok2=false;
@@ -198,7 +198,7 @@ void ConstraintActivityPreferredRoomForm::constraintChanged(int index)
 	}
 	assert(index<this->visibleConstraintsList.size());
 	SpaceConstraint* ctr=this->visibleConstraintsList.at(index);
-	assert(ctr!=NULL);
+	assert(ctr!=nullptr);
 	currentConstraintTextEdit->setPlainText(ctr->getDetailedDescription(gt.rules));
 }
 
@@ -259,7 +259,7 @@ void ConstraintActivityPreferredRoomForm::removeConstraint()
 	QListWidgetItem* item;
 
 	switch( LongTextMessageBox::confirmation( this, tr("FET confirmation"),
-		s, tr("Yes"), tr("No"), 0, 0, 1 ) ){
+		s, tr("Yes"), tr("No"), QString(), 0, 1 ) ){
 	case 0: // The user clicked the OK button or pressed Enter
 		gt.rules.removeSpaceConstraint(ctr);
 		
