@@ -110,15 +110,15 @@ bool ConstraintActivityPreferredTimeSlotsForm::filterOk(TimeConstraint* ctr)
 	bool found=true;
 	
 	int id=c->p_activityId;
-	/*Activity* act=NULL;
+	/*Activity* act=nullptr;
 	for(Activity* a : qAsConst(gt.rules.activitiesList))
 		if(a->id==id)
 			act=a;*/
-	Activity* act=gt.rules.activitiesPointerHash.value(id, NULL);
+	Activity* act=gt.rules.activitiesPointerHash.value(id, nullptr);
 	
 	found=true;
 	
-	if(act!=NULL){
+	if(act!=nullptr){
 		//teacher
 		if(tn!=""){
 			bool ok2=false;
@@ -184,7 +184,7 @@ void ConstraintActivityPreferredTimeSlotsForm::constraintChanged(int index)
 	}
 	assert(index<this->visibleConstraintsList.size());
 	TimeConstraint* ctr=this->visibleConstraintsList.at(index);
-	assert(ctr!=NULL);
+	assert(ctr!=nullptr);
 	currentConstraintTextEdit->setPlainText(ctr->getDetailedDescription(gt.rules));
 }
 
@@ -245,7 +245,7 @@ void ConstraintActivityPreferredTimeSlotsForm::removeConstraint()
 	QListWidgetItem* item;
 
 	switch( LongTextMessageBox::confirmation( this, tr("FET confirmation"),
-		s, tr("Yes"), tr("No"), 0, 0, 1 ) ){
+		s, tr("Yes"), tr("No"), QString(), 0, 1 ) ){
 	case 0: // The user clicked the OK button or pressed Enter
 		gt.rules.removeTimeConstraint(ctr);
 		
