@@ -105,7 +105,7 @@ void ConstraintStudentsActivityTagMinHoursDailyForm::constraintChanged(int index
 	}
 	assert(index<this->visibleConstraintsList.size());
 	TimeConstraint* ctr=this->visibleConstraintsList.at(index);
-	assert(ctr!=NULL);
+	assert(ctr!=nullptr);
 	currentConstraintTextEdit->setPlainText(ctr->getDetailedDescription(gt.rules));
 }
 
@@ -166,7 +166,7 @@ void ConstraintStudentsActivityTagMinHoursDailyForm::removeConstraint()
 	QListWidgetItem* item;
 
 	switch( LongTextMessageBox::confirmation( this, tr("FET confirmation"),
-		s, tr("Yes"), tr("No"), 0, 0, 1 ) ){
+		s, tr("Yes"), tr("No"), QString(), 0, 1 ) ){
 	case 0: // The user clicked the OK button or pressed Enter
 		gt.rules.removeTimeConstraint(ctr);
 		
