@@ -33,6 +33,14 @@ ConstraintStudentsSetMinHoursDailyForm::ConstraintStudentsSetMinHoursDailyForm(Q
 {
 	setupUi(this);
 
+	if(gt.rules.mode!=MORNINGS_AFTERNOONS)
+		label->setText(tr("IMPORTANT: allow empty days for students is a nonstandard option. Only select it if your institution permits that"
+		 " and if a timetable with empty days for students exists. Otherwise do not select it, for a good performance of generation."
+		 " Press Help button for more information."));
+	else
+		label->setText(tr("If the user selects not allowed empty days, it is for real days (for the mornings-afternoons mode), also respecting minimum"
+		 " hours daily for FET days (half days) with allow empty FET days"));
+
 	currentConstraintTextEdit->setReadOnly(true);
 	
 	modifyConstraintPushButton->setDefault(true);
@@ -102,7 +110,7 @@ void ConstraintStudentsSetMinHoursDailyForm::constraintChanged(int index)
 	}
 	assert(index<this->visibleConstraintsList.size());
 	TimeConstraint* ctr=this->visibleConstraintsList.at(index);
-	assert(ctr!=NULL);
+	assert(ctr!=nullptr);
 	currentConstraintTextEdit->setPlainText(ctr->getDetailedDescription(gt.rules));
 }
 
@@ -163,7 +171,7 @@ void ConstraintStudentsSetMinHoursDailyForm::removeConstraint()
 	QListWidgetItem* item;
 
 	switch( LongTextMessageBox::confirmation( this, tr("FET confirmation"),
-		s, tr("Yes"), tr("No"), 0, 0, 1 ) ){
+		s, tr("Yes"), tr("No"), QString(), 0, 1 ) ){
 	case 0: // The user clicked the OK button or pressed Enter
 		gt.rules.removeTimeConstraint(ctr);
 		
