@@ -124,13 +124,13 @@ bool ConstraintTwoActivitiesOrderedIfSameDayForm::filterOk(TimeConstraint* ctr)
 			
 		assert(id>=0);
 
-		/*Activity* act=NULL;
+		/*Activity* act=nullptr;
 		for(Activity* a : qAsConst(gt.rules.activitiesList))
 			if(a->id==id)
 				act=a;*/
-		Activity* act=gt.rules.activitiesPointerHash.value(id, NULL);
+		Activity* act=gt.rules.activitiesPointerHash.value(id, nullptr);
 		
-		if(act!=NULL){
+		if(act!=nullptr){
 			//teacher
 			if(tn!=""){
 				bool ok2=false;
@@ -205,7 +205,7 @@ void ConstraintTwoActivitiesOrderedIfSameDayForm::constraintChanged(int index)
 	}
 	assert(index<this->visibleConstraintsList.size());
 	TimeConstraint* ctr=this->visibleConstraintsList.at(index);
-	assert(ctr!=NULL);
+	assert(ctr!=nullptr);
 	currentConstraintTextEdit->setPlainText(ctr->getDetailedDescription(gt.rules));
 }
 
@@ -264,7 +264,7 @@ void ConstraintTwoActivitiesOrderedIfSameDayForm::removeConstraint()
 	QListWidgetItem* item;
 
 	switch( LongTextMessageBox::confirmation( this, tr("FET confirmation"),
-		s, tr("Yes"), tr("No"), 0, 0, 1 ) ){
+		s, tr("Yes"), tr("No"), QString(), 0, 1 ) ){
 	case 0: // The user clicked the OK button or pressed Enter
 		gt.rules.removeTimeConstraint(ctr);
 		
