@@ -119,13 +119,13 @@ bool GroupActivitiesInInitialOrderItemsForm::filterOk(const GroupActivitiesInIni
 		
 	for(int i=0; i<item.ids.count(); i++){
 		int id=item.ids.at(i);
-		/*Activity* act=NULL;
+		/*Activity* act=nullptr;
 		for(Activity* a : qAsConst(gt.rules.activitiesList))
 			if(a->id==id)
 				act=a;*/
-		Activity* act=gt.rules.activitiesPointerHash.value(id, NULL);
+		Activity* act=gt.rules.activitiesPointerHash.value(id, nullptr);
 		
-		if(act!=NULL){
+		if(act!=nullptr){
 			//teacher
 			if(tn!=""){
 				bool ok2=false;
@@ -271,7 +271,7 @@ void GroupActivitiesInInitialOrderItemsForm::removeItem()
 	s+=item->getDetailedDescription(gt.rules);
 	
 	switch( LongTextMessageBox::confirmation( this, tr("FET confirmation"),
-		s, tr("Yes"), tr("No"), 0, 0, 1 ) ){
+		s, tr("Yes"), tr("No"), QString(), 0, 1 ) ){
 	case 0: // The user clicked the OK button or pressed Enter
 		for(int j=0; j<gt.rules.groupActivitiesInInitialOrderList.count(); j++)
 			if(visibleItemsList.at(i) == gt.rules.groupActivitiesInInitialOrderList[j]){
