@@ -130,7 +130,7 @@ void GroupsForm::addExistingGroups()
 	}
 	QString yearName=yearsListWidget->currentItem()->text();
 	
-	StudentsYear* year=NULL;
+	StudentsYear* year=nullptr;
 	
 	for(StudentsYear* sty : qAsConst(gt.rules.yearsList))
 		if(sty->name==yearName){
@@ -138,7 +138,7 @@ void GroupsForm::addExistingGroups()
 			break;
 		}
 		
-	assert(year!=NULL);
+	assert(year!=nullptr);
 	
 	AddExistingStudentsGroupsForm form(this, year);
 	setParentAndOtherThings(&form, this);
@@ -201,7 +201,7 @@ void GroupsForm::removeGroup()
 
 	/*if(QMessageBox::warning( this, tr("FET"),
 		tr("Are you sure you want to delete group %1 and all related subgroups, activities and constraints?").arg(groupName),
-		tr("Yes"), tr("No"), 0, 0, 1 ) == 1)
+		tr("Yes"), tr("No"), QString(), 0, 1 ) == 1)
 		return;*/
 
 	bool tmp=gt.rules.removeGroup(yearsListWidget->currentItem()->text(), groupName);
@@ -222,7 +222,7 @@ void GroupsForm::removeGroup()
 			groupTextEdit->setPlainText(QString(""));
 	}
 
-	/*if(gt.rules.searchStudentsSet(groupName)!=NULL)
+	/*if(gt.rules.searchStudentsSet(groupName)!=nullptr)
 		QMessageBox::information( this, tr("FET"), tr("This group still exists into another year. "
 			"The related subgroups, activities and constraints were not removed"));*/
 }
@@ -272,7 +272,7 @@ void GroupsForm::purgeGroup()
 
 	/*if(QMessageBox::warning( this, tr("FET"),
 		tr("Are you sure you want to delete group %1 and all related subgroups, activities and constraints?").arg(groupName),
-		tr("Yes"), tr("No"), 0, 0, 1 ) == 1)
+		tr("Yes"), tr("No"), QString(), 0, 1 ) == 1)
 		return;*/
 
 	bool tmp=gt.rules.purgeGroup(groupName);
@@ -293,12 +293,12 @@ void GroupsForm::purgeGroup()
 			groupTextEdit->setPlainText(QString(""));
 	}
 
-	/*if(gt.rules.searchStudentsSet(groupName)!=NULL)
+	/*if(gt.rules.searchStudentsSet(groupName)!=nullptr)
 		QMessageBox::information( this, tr("FET"), tr("This group still exists into another year. "
 			"The related subgroups, activities and constraints were not removed"));*/
 }
 
-void GroupsForm::yearChanged(const QString &yearName)
+void GroupsForm::yearChanged(const QString& yearName)
 {
 	int yearIndex=gt.rules.searchYear(yearName);
 	if(yearIndex<0){
@@ -321,10 +321,10 @@ void GroupsForm::yearChanged(const QString &yearName)
 		groupTextEdit->setPlainText(QString(""));
 }
 
-void GroupsForm::groupChanged(const QString &groupName)
+void GroupsForm::groupChanged(const QString& groupName)
 {
 	StudentsSet* ss=gt.rules.searchStudentsSet(groupName);
-	if(ss==NULL){
+	if(ss==nullptr){
 		groupTextEdit->setPlainText(QString(""));
 		return;
 	}
@@ -445,9 +445,9 @@ void GroupsForm::modifyGroup()
 	int groupIndex=gt.rules.searchGroup(yearsListWidget->currentItem()->text(), groupName);
 	assert(groupIndex>=0);
 
-	StudentsSet* sset=gt.rules.searchStudentsSet(groupName);
-	assert(sset!=NULL);
-	int numberOfStudents=sset->numberOfStudents;
+	StudentsSet* studentsSet=gt.rules.searchStudentsSet(groupName);
+	assert(studentsSet!=nullptr);
+	int numberOfStudents=studentsSet->numberOfStudents;
 	
 	ModifyStudentsGroupForm form(this, yearName, groupName, numberOfStudents);
 	setParentAndOtherThings(&form, this);
@@ -501,7 +501,7 @@ void GroupsForm::deactivateStudents()
 
 	QString groupName=groupsListWidget->currentItem()->text();
 	int count=gt.rules.deactivateStudents(groupName);
-	QMessageBox::information(this, tr("FET information"), tr("De-activated a number of %1 activities").arg(count));
+	QMessageBox::information(this, tr("FET information"), tr("Deactivated a number of %1 activities").arg(count));
 }
 
 void GroupsForm::comments()
@@ -514,8 +514,8 @@ void GroupsForm::comments()
 	
 	QString groupName=groupsListWidget->currentItem()->text();
 	
-	StudentsSet* sset=gt.rules.searchStudentsSet(groupName);
-	assert(sset!=NULL);
+	StudentsSet* studentsSet=gt.rules.searchStudentsSet(groupName);
+	assert(studentsSet!=nullptr);
 
 	QDialog getCommentsDialog(this);
 	
@@ -536,7 +536,7 @@ void GroupsForm::comments()
 	QVBoxLayout* vl=new QVBoxLayout();
 	
 	QPlainTextEdit* commentsPT=new QPlainTextEdit();
-	commentsPT->setPlainText(sset->comments);
+	commentsPT->setPlainText(studentsSet->comments);
 	commentsPT->selectAll();
 	commentsPT->setFocus();
 	
@@ -555,7 +555,7 @@ void GroupsForm::comments()
 	saveFETDialogGeometry(&getCommentsDialog, settingsName);
 	
 	if(t==QDialog::Accepted){
-		sset->comments=commentsPT->toPlainText();
+		studentsSet->comments=commentsPT->toPlainText();
 	
 		gt.rules.internalStructureComputed=false;
 		setRulesModifiedAndOtherThings(&gt.rules);
