@@ -19,8 +19,6 @@
 
 #include <QMessageBox>
 
-#include "tablewidgetupdatebug.h"
-
 #include "longtextmessagebox.h"
 
 #include "modifyconstraintactivitiesoccupymaxtimeslotsfromselectionform.h"
@@ -84,7 +82,6 @@ ModifyConstraintActivitiesOccupyMaxTimeSlotsFromSelectionForm::ModifyConstraintA
 		selectedTimesTable->setVerticalHeaderItem(i, item);
 	}
 
-	//bool currentMatrix[MAX_HOURS_PER_DAY][MAX_DAYS_PER_WEEK];
 	Matrix2D<bool> currentMatrix;
 	currentMatrix.resize(gt.rules.nHoursPerDay, gt.rules.nDaysPerWeek);
 
@@ -125,8 +122,6 @@ ModifyConstraintActivitiesOccupyMaxTimeSlotsFromSelectionForm::ModifyConstraintA
 
 	selectedTimesTable->setSelectionMode(QAbstractItemView::NoSelection);
 	
-	tableWidgetUpdateBug(selectedTimesTable);
-	
 	setStretchAvailabilityTableNicely(selectedTimesTable);
 	
 	//activities
@@ -144,13 +139,8 @@ ModifyConstraintActivitiesOccupyMaxTimeSlotsFromSelectionForm::ModifyConstraintA
 	for(int i=0; i<ctr->activitiesIds.count(); i++){
 		int actId=ctr->activitiesIds.at(i);
 		this->selectedActivitiesList.append(actId);
-		Activity* act=NULL;
-		for(int k=0; k<gt.rules.activitiesList.size(); k++){
-			act=gt.rules.activitiesList[k];
-			if(act->id==actId)
-				break;
-		}
-		assert(act);
+		Activity *act=gt.rules.activitiesPointerHash.value(actId, nullptr);
+		assert(act!=nullptr);
 		this->selectedActivitiesListWidget->addItem(act->getDescription(gt.rules));
 	}
 
@@ -225,7 +215,6 @@ void ModifyConstraintActivitiesOccupyMaxTimeSlotsFromSelectionForm::horizontalHe
 			selectedTimesTable->item(row, col)->setText(s);
 			colorItem(selectedTimesTable->item(row,col));
 		}
-		tableWidgetUpdateBug(selectedTimesTable);
 	}
 }
 
@@ -244,7 +233,6 @@ void ModifyConstraintActivitiesOccupyMaxTimeSlotsFromSelectionForm::verticalHead
 			selectedTimesTable->item(row, col)->setText(s);
 			colorItem(selectedTimesTable->item(row,col));
 		}
-		tableWidgetUpdateBug(selectedTimesTable);
 	}
 }
 
@@ -255,7 +243,6 @@ void ModifyConstraintActivitiesOccupyMaxTimeSlotsFromSelectionForm::setAllUnsele
 			selectedTimesTable->item(i, j)->setText(NO);
 			colorItem(selectedTimesTable->item(i,j));
 		}
-	tableWidgetUpdateBug(selectedTimesTable);
 }
 
 void ModifyConstraintActivitiesOccupyMaxTimeSlotsFromSelectionForm::setAllSelected()
@@ -265,7 +252,6 @@ void ModifyConstraintActivitiesOccupyMaxTimeSlotsFromSelectionForm::setAllSelect
 			selectedTimesTable->item(i, j)->setText(YES);
 			colorItem(selectedTimesTable->item(i,j));
 		}
-	tableWidgetUpdateBug(selectedTimesTable);
 }
 
 void ModifyConstraintActivitiesOccupyMaxTimeSlotsFromSelectionForm::itemClicked(QTableWidgetItem* item)
@@ -279,8 +265,6 @@ void ModifyConstraintActivitiesOccupyMaxTimeSlotsFromSelectionForm::itemClicked(
 	}
 	item->setText(s);
 	colorItem(item);
-	
-	tableWidgetUpdateBug(selectedTimesTable);
 }
 
 void ModifyConstraintActivitiesOccupyMaxTimeSlotsFromSelectionForm::ok()
