@@ -19,8 +19,6 @@
 
 #include <QMessageBox>
 
-#include "tablewidgetupdatebug.h"
-
 #include "modifyconstraintactivitiespreferredstartingtimesform.h"
 #include "timeconstraint.h"
 
@@ -87,7 +85,6 @@ ModifyConstraintActivitiesPreferredStartingTimesForm::ModifyConstraintActivities
 		preferredTimesTable->setVerticalHeaderItem(i, item);
 	}
 
-	//bool currentMatrix[MAX_HOURS_PER_DAY][MAX_DAYS_PER_WEEK];
 	Matrix2D<bool> currentMatrix;
 	currentMatrix.resize(gt.rules.nHoursPerDay, gt.rules.nDaysPerWeek);
 	
@@ -119,9 +116,9 @@ ModifyConstraintActivitiesPreferredStartingTimesForm::ModifyConstraintActivities
 				
 			colorItem(item);
 		}
-		
+	
 	preferredTimesTable->resizeRowsToContents();
-				
+	
 	weightLineEdit->setText(CustomFETString::number(ctr->weightPercentage));
 
 	connect(preferredTimesTable->horizontalHeader(), SIGNAL(sectionClicked(int)), this, SLOT(horizontalHeaderClicked(int)));
@@ -129,8 +126,6 @@ ModifyConstraintActivitiesPreferredStartingTimesForm::ModifyConstraintActivities
 
 	preferredTimesTable->setSelectionMode(QAbstractItemView::NoSelection);
 
-	tableWidgetUpdateBug(preferredTimesTable);
-	
 	setStretchAvailabilityTableNicely(preferredTimesTable);
 }
 
@@ -173,7 +168,6 @@ void ModifyConstraintActivitiesPreferredStartingTimesForm::horizontalHeaderClick
 			preferredTimesTable->item(row, col)->setText(s);
 			colorItem(preferredTimesTable->item(row,col));
 		}
-		tableWidgetUpdateBug(preferredTimesTable);
 	}
 }
 
@@ -192,7 +186,6 @@ void ModifyConstraintActivitiesPreferredStartingTimesForm::verticalHeaderClicked
 			preferredTimesTable->item(row, col)->setText(s);
 			colorItem(preferredTimesTable->item(row,col));
 		}
-		tableWidgetUpdateBug(preferredTimesTable);
 	}
 }
 
@@ -203,7 +196,6 @@ void ModifyConstraintActivitiesPreferredStartingTimesForm::setAllSlotsAllowed()
 			preferredTimesTable->item(i, j)->setText(YES);
 			colorItem(preferredTimesTable->item(i,j));
 		}
-	tableWidgetUpdateBug(preferredTimesTable);
 }
 
 void ModifyConstraintActivitiesPreferredStartingTimesForm::setAllSlotsNotAllowed()
@@ -213,7 +205,6 @@ void ModifyConstraintActivitiesPreferredStartingTimesForm::setAllSlotsNotAllowed
 			preferredTimesTable->item(i, j)->setText(NO);
 			colorItem(preferredTimesTable->item(i,j));
 		}
-	tableWidgetUpdateBug(preferredTimesTable);
 }
 
 void ModifyConstraintActivitiesPreferredStartingTimesForm::itemClicked(QTableWidgetItem* item)
@@ -227,8 +218,6 @@ void ModifyConstraintActivitiesPreferredStartingTimesForm::itemClicked(QTableWid
 	}
 	item->setText(s);
 	colorItem(item);
-
-	tableWidgetUpdateBug(preferredTimesTable);
 }
 
 void ModifyConstraintActivitiesPreferredStartingTimesForm::updateTeachersComboBox(){
@@ -322,7 +311,7 @@ void ModifyConstraintActivitiesPreferredStartingTimesForm::ok()
 
 	QString students=studentsComboBox->currentText();
 	if(students!="")
-		assert(gt.rules.searchStudentsSet(students)!=NULL);
+		assert(gt.rules.searchStudentsSet(students)!=nullptr);
 
 	QString subject=subjectsComboBox->currentText();
 	if(subject!="")
