@@ -19,8 +19,6 @@
 
 #include <QMessageBox>
 
-#include "tablewidgetupdatebug.h"
-
 #include "modifyconstraintactivitiespreferredtimeslotsform.h"
 #include "timeconstraint.h"
 
@@ -87,7 +85,6 @@ ModifyConstraintActivitiesPreferredTimeSlotsForm::ModifyConstraintActivitiesPref
 		preferredTimesTable->setVerticalHeaderItem(i, item);
 	}
 
-	//bool currentMatrix[MAX_HOURS_PER_DAY][MAX_DAYS_PER_WEEK];
 	Matrix2D<bool> currentMatrix;
 	currentMatrix.resize(gt.rules.nHoursPerDay, gt.rules.nDaysPerWeek);
 	
@@ -121,7 +118,7 @@ ModifyConstraintActivitiesPreferredTimeSlotsForm::ModifyConstraintActivitiesPref
 		}
 		
 	preferredTimesTable->resizeRowsToContents();
-				
+	
 	weightLineEdit->setText(CustomFETString::number(ctr->weightPercentage));
 
 	connect(preferredTimesTable->horizontalHeader(), SIGNAL(sectionClicked(int)), this, SLOT(horizontalHeaderClicked(int)));
@@ -129,8 +126,6 @@ ModifyConstraintActivitiesPreferredTimeSlotsForm::ModifyConstraintActivitiesPref
 
 	preferredTimesTable->setSelectionMode(QAbstractItemView::NoSelection);
 
-	tableWidgetUpdateBug(preferredTimesTable);
-	
 	setStretchAvailabilityTableNicely(preferredTimesTable);
 }
 
@@ -173,7 +168,6 @@ void ModifyConstraintActivitiesPreferredTimeSlotsForm::horizontalHeaderClicked(i
 			preferredTimesTable->item(row, col)->setText(s);
 			colorItem(preferredTimesTable->item(row,col));
 		}
-		tableWidgetUpdateBug(preferredTimesTable);
 	}
 }
 
@@ -192,7 +186,6 @@ void ModifyConstraintActivitiesPreferredTimeSlotsForm::verticalHeaderClicked(int
 			preferredTimesTable->item(row, col)->setText(s);
 			colorItem(preferredTimesTable->item(row,col));
 		}
-		tableWidgetUpdateBug(preferredTimesTable);
 	}
 }
 
@@ -203,7 +196,6 @@ void ModifyConstraintActivitiesPreferredTimeSlotsForm::setAllSlotsAllowed()
 			preferredTimesTable->item(i, j)->setText(YES);
 			colorItem(preferredTimesTable->item(i,j));
 		}
-	tableWidgetUpdateBug(preferredTimesTable);
 }
 
 void ModifyConstraintActivitiesPreferredTimeSlotsForm::setAllSlotsNotAllowed()
@@ -213,7 +205,6 @@ void ModifyConstraintActivitiesPreferredTimeSlotsForm::setAllSlotsNotAllowed()
 			preferredTimesTable->item(i, j)->setText(NO);
 			colorItem(preferredTimesTable->item(i,j));
 		}
-	tableWidgetUpdateBug(preferredTimesTable);
 }
 
 void ModifyConstraintActivitiesPreferredTimeSlotsForm::itemClicked(QTableWidgetItem* item)
@@ -227,7 +218,6 @@ void ModifyConstraintActivitiesPreferredTimeSlotsForm::itemClicked(QTableWidgetI
 	}
 	item->setText(s);
 	colorItem(item);
-	tableWidgetUpdateBug(preferredTimesTable);
 }
 
 void ModifyConstraintActivitiesPreferredTimeSlotsForm::updateTeachersComboBox(){
@@ -321,7 +311,7 @@ void ModifyConstraintActivitiesPreferredTimeSlotsForm::ok()
 
 	QString students=studentsComboBox->currentText();
 	if(students!="")
-		assert(gt.rules.searchStudentsSet(students)!=NULL);
+		assert(gt.rules.searchStudentsSet(students)!=nullptr);
 
 	QString subject=subjectsComboBox->currentText();
 	if(subject!="")
