@@ -18,7 +18,6 @@
 #include <QMessageBox>
 
 #include "modifyconstraintactivitiessamestartingtimeform.h"
-#include "spaceconstraint.h"
 
 #include <QList>
 
@@ -65,13 +64,8 @@ ModifyConstraintActivitiesSameStartingTimeForm::ModifyConstraintActivitiesSameSt
 	for(int i=0; i<ctr->n_activities; i++){
 		int actId=ctr->activitiesId[i];
 		this->selectedActivitiesList.append(actId);
-		Activity* act=NULL;
-		for(int k=0; k<gt.rules.activitiesList.size(); k++){
-			act=gt.rules.activitiesList[k];
-			if(act->id==actId)
-				break;
-		}
-		assert(act);
+		Activity *act=gt.rules.activitiesPointerHash.value(actId, nullptr);
+		assert(act!=nullptr);
 		selectedActivitiesListWidget->addItem(act->getDescription(gt.rules));
 	}
 
